@@ -139,11 +139,11 @@ perl_server_cb (char *word[], char *word_eol[], void *perl_callback)
 	return execute_perl (perl_callback, word_eol[1]);
 }
 
-/*static int
+static int
 perl_command_cb (char *word[], char *word_eol[], void *perl_callback)
 {
-	return execute_perl (perl_callback, word_eol[1]);
-}*/
+	return execute_perl (perl_callback, word_eol[2]);
+}
 
 static int
 perl_print_cb (char *word[], void *perl_callback)
@@ -330,7 +330,7 @@ static XS (XS_IRC_add_command_handler)
 	tmp = strdup (SvPV (ST (1), junk));
 
 	hook = xchat_hook_command (ph, SvPV (ST (0), junk), PRI_NORM,
-										perl_server_cb, NULL, tmp);
+										perl_command_cb, NULL, tmp);
 
 	hook_list = g_slist_prepend (hook_list, hook);
 
