@@ -1471,11 +1471,11 @@ Module_xchat_get_list(PyObject *self, PyObject *args)
 			switch(fields[i][0]) {
 			case 's':
 				sattr = xchat_list_str(ph, list, (char*)fld);
-				attr = PyString_FromString(sattr);
+				attr = PyString_FromString(sattr?sattr:"");
 				break;
 			case 'i':
 				iattr = xchat_list_int(ph, list, (char*)fld);
-				attr = PyInt_FromLong((long)i);
+				attr = PyInt_FromLong((long)iattr);
 				break;
 			case 'p':
 				sattr = xchat_list_str(ph, list, (char*)fld);
