@@ -300,8 +300,6 @@ const struct prefs vars[] = {
 	{"completion_old", P_OFFINT (old_nickcompletion), TYPE_BOOL},
 	{"completion_suffix", P_OFFSET (nick_suffix), TYPE_STR},
 
-	{"channelbox", P_OFFINT (channelbox), TYPE_INT},/* only in old-serverlist.c */
-
 	{"dcc_auto_chat", P_OFFINT (autodccchat), TYPE_BOOL},
 	{"dcc_auto_resume", P_OFFINT (autoresume), TYPE_BOOL},
 	{"dcc_auto_send", P_OFFINT (autodccsend), TYPE_BOOL},
@@ -337,7 +335,8 @@ const struct prefs vars[] = {
 	{"gui_hide_menu", P_OFFINT (hidemenu), TYPE_BOOL},
 	{"gui_input_style", P_OFFINT (style_inputbox), TYPE_BOOL},
 	{"gui_lagometer", P_OFFINT (lagometer), TYPE_INT},
-	{"gui_skip_serverlist", P_OFFINT (skipserverlist), TYPE_BOOL},
+	{"gui_slist_edit", P_OFFINT (slist_edit), TYPE_BOOL},
+	{"gui_slist_skip", P_OFFINT (slist_skip), TYPE_BOOL},
 	{"gui_throttlemeter", P_OFFINT (throttlemeter), TYPE_INT},
 	{"gui_treeview", P_OFFINT (treeview), TYPE_BOOL},
 	{"gui_topicbar", P_OFFINT (topicbar), TYPE_BOOL},
@@ -428,17 +427,14 @@ const struct prefs vars[] = {
 	{"text_color_nicks", P_OFFINT (colorednicks), TYPE_BOOL},
 	{"text_background", P_OFFSET (background), TYPE_STR},
 	{"text_font", P_OFFSET (font_normal), TYPE_STR},
-	{"text_fontset", P_OFFINT (use_fontset), TYPE_BOOL},
 	{"text_indent", P_OFFINT (indent_nicks), TYPE_BOOL},
 	{"text_max_indent", P_OFFINT (max_auto_indent), TYPE_INT},
 	{"text_max_lines", P_OFFINT (max_lines), TYPE_INT},
 	{"text_thin_sep", P_OFFINT (thin_separator), TYPE_BOOL},
 	{"text_tint", P_OFFINT (tint), TYPE_BOOL},
-#ifndef WIN32
 	{"text_tint_blue", P_OFFINT (tint_blue), TYPE_INT},
 	{"text_tint_green", P_OFFINT (tint_green), TYPE_INT},
 	{"text_tint_red", P_OFFINT (tint_red), TYPE_INT},
-#endif
 	{"text_transparent", P_OFFINT (transparent), TYPE_BOOL},
 	{"text_show_sep", P_OFFINT (show_separator), TYPE_BOOL},
 	{"text_stripcolor", P_OFFINT (stripcolor), TYPE_BOOL},
