@@ -44,6 +44,7 @@
 #include "plugin.h"
 #include "server.h"
 #include "text.h"
+#include "url.h"
 #include "xchatc.h"
 
 
@@ -356,7 +357,7 @@ dcc_chat_line (struct DCC *dcc, char *line, char *tbuf)
 	char *po;
 	int ret, i;
 
-	sess = find_session_from_channel (dcc->nick, dcc->serv);
+	sess = find_dialog (dcc->serv, dcc->nick);
 	if (!sess)
 		sess = dcc->serv->front_session;
 
@@ -380,7 +381,7 @@ dcc_chat_line (struct DCC *dcc, char *line, char *tbuf)
 	if (ret)
 		return 0;
 
-	fe_checkurl (line);
+	url_check (line);
 
 	if (line[0] == 1 && !strncasecmp (line + 1, "ACTION", 6))
 	{
@@ -548,8 +549,11 @@ dcc_connect_finished (GIOChannel *source, GIOCondition condition, struct DCC *dc
 	char host[128];
 	struct sockaddr_in addr;
 
-	fe_input_remove (dcc->iotag);
-	dcc->iotag = 0;
+	if (dcc->iotag)
+	{
+		fe_input_remove (dcc->iotag);
+		dcc->iotag = 0;
+	}
 
 	memset (&addr, 0, sizeof (addr));
 	addr.sin_port = htons (dcc->port);
@@ -576,43 +580,76 @@ dcc_connect_finished (GIOChannel *source, GIOCondition condition, struct DCC *dc
 	}
 
 	dcc->dccstat = STAT_ACTIVE;
+	snprintf (host, sizeof host, "%s:%d", net_ip (dcc->addr), dcc->port);
+
 	switch (dcc->type)
 	{
 	case TYPE_RECV:
 		dcc->iotag = fe_input_add (dcc->sok, 1, 0, 1, dcc_read, dcc);
+		EMIT_SIGNAL (XP_TE_DCCCONRECV, dcc->serv->front_session,
+						 dcc->nick, host, dcc->file, NULL, 0);
 		break;
 
 	case TYPE_CHATRECV:
 		dcc->iotag = fe_input_add (dcc->sok, 1, 0, 1, dcc_read_chat, dcc);
 		dcc->dccchat = malloc (sizeof (struct dcc_chat));
 		dcc->dccchat->pos = 0;
+		EMIT_SIGNAL (XP_TE_DCCCONCHAT, dcc->serv->front_session,
+						 dcc->nick, host, NULL, NULL, 0);
 		break;
 	}
 	update_dcc_window (dcc->type);
 	dcc->starttime = time (0);
 	dcc->lasttime = dcc->starttime;
 
-	snprintf (host, sizeof host, "%s:%d", net_ip (dcc->addr), dcc->port);
-	EMIT_SIGNAL (XP_TE_DCCCONRECV, dcc->serv->front_session,
-					 dcc->nick, host, dcc->file, NULL, 0);
-
 	return TRUE;
 }
 
+static int dcc_listen_init (struct DCC *, struct session *);
+
 static void
 dcc_connect (struct DCC *dcc)
 {
+	int ret;
+	char tbuf[400];
+
 	if (dcc->dccstat == STAT_CONNECTING)
 		return;
 	dcc->dccstat = STAT_CONNECTING;
-	dcc->sok = dcc_connect_sok (dcc);
-	if (dcc->sok == -1)
+
+	if (dcc->pasvid)
 	{
-		dcc->dccstat = STAT_FAILED;
-		update_dcc_window (dcc->type);
-		return;
+		/* accepted a passive dcc send */
+		ret = dcc_listen_init (dcc, dcc->serv->front_session);
+		if (!ret)
+		{
+			dcc_close (dcc, STAT_FAILED, FALSE);
+			return;
+		}
+		/* possible problems with filenames containing spaces? */
+		if (dcc->type == TYPE_RECV)
+			snprintf (tbuf, sizeof (tbuf), strchr (dcc->file, ' ') ?
+					"DCC SEND \"%s\" %lu %d %u %d" :
+					"DCC SEND %s %lu %d %u %d", dcc->file,
+					dcc->addr, dcc->port, dcc->size, dcc->pasvid);
+		else
+			snprintf (tbuf, sizeof (tbuf), "DCC CHAT chat %lu %d %d",
+				dcc->addr, dcc->port, dcc->pasvid);
+
+		dcc->serv->p_ctcp (dcc->serv, dcc->nick, tbuf);
 	}
-	dcc->iotag = fe_input_add (dcc->sok, 0, 1, 1, dcc_connect_finished, dcc);
+	else
+	{
+		dcc->sok = dcc_connect_sok (dcc);
+		if (dcc->sok == -1)
+		{
+			dcc->dccstat = STAT_FAILED;
+			update_dcc_window (dcc->type);
+			return;
+		}
+		dcc->iotag = fe_input_add (dcc->sok, 0, 1, 1, dcc_connect_finished, dcc);
+	}
+	
 	if (dcc->type == TYPE_RECV)
 		fe_dcc_update_recv (dcc);
 	else
@@ -745,6 +782,10 @@ dcc_accept (GIOChannel *source, GIOCondition condition, struct DCC *dcc)
 	set_nonblocking (sok);
 	dcc->sok = sok;
 	dcc->addr = ntohl (CAddr.sin_addr.s_addr);
+
+	if (dcc->pasvid)
+		return dcc_connect_finished (NULL, 0, dcc);
+
 	dcc->dccstat = STAT_ACTIVE;
 	dcc->lasttime = dcc->starttime = time (0);
 	dcc->fastsend = prefs.fastdccsend;
@@ -876,6 +917,7 @@ dcc_send_wild (char *file)
 void
 dcc_send (session *sess, char *tbuf, char *to, char *file)
 {
+	char outbuf[512];
 	struct stat st;
 	struct DCC *dcc;
 
@@ -943,12 +985,14 @@ dcc_send (session *sess, char *tbuf, char *to, char *file)
 							fe_dcc_open_send_win (TRUE);
 						else
 							fe_dcc_update_send_win ();
-						
-						tcp_sendf (sess->server, (havespaces) ?
-								"PRIVMSG %s :\001DCC SEND \"%s\" %lu %d %d\001\r\n" :
-								"PRIVMSG %s :\001DCC SEND %s %lu %d %d\001\r\n",
-								 to, file_part (dcc->file), dcc->addr, dcc->port,
-								 dcc->size);
+
+						snprintf (outbuf, sizeof (outbuf), (havespaces) ? 
+								"DCC SEND \"%s\" %lu %d %u" :
+								"DCC SEND %s %lu %d %u",
+								 file_part (dcc->file), dcc->addr,
+								 dcc->port, dcc->size);
+						sess->server->p_ctcp (sess->server, to, outbuf);
+
 						EMIT_SIGNAL (XP_TE_DCCOFFER, sess, file_part (dcc->file),
 										 to, dcc->file, NULL, 0);
 					} else
@@ -1091,6 +1135,7 @@ new_dcc (void)
 void
 dcc_chat (struct session *sess, char *nick)
 {
+	char outbuf[512];
 	struct DCC *dcc;
 
 	dcc = find_dcc (nick, "", TYPE_CHATSEND);
@@ -1138,9 +1183,9 @@ dcc_chat (struct session *sess, char *nick)
 			fe_dcc_open_chat_win (TRUE);
 		else
 			fe_dcc_update_chat_win ();
-		tcp_sendf (dcc->serv,
-					  "PRIVMSG %s :\001DCC CHAT chat %lu %d\001\r\n", nick,
-					  dcc->addr, dcc->port);
+		snprintf (outbuf, sizeof (outbuf), "DCC CHAT chat %lu %d",
+						dcc->addr, dcc->port);
+		dcc->serv->p_ctcp (dcc->serv, nick, outbuf);
 		EMIT_SIGNAL (XP_TE_DCCCHATOFFERING, sess, nick, NULL, NULL, NULL, 0);
 	} else
 	{
@@ -1157,13 +1202,20 @@ dcc_malformed (struct session *sess, char *nick, char *data)
 void
 dcc_resume (struct DCC *dcc)
 {
+	char tbuf[500];
+
 	if (dcc->dccstat == STAT_QUEUED && dcc->resumable)
 	{
 		/* filename contains spaces? Quote them! */
-		tcp_sendf (dcc->serv, (strchr (dcc->file, ' ')) ?
-					  "PRIVMSG %s :\001DCC RESUME \"%s\" %d %d\001\r\n" :
-					  "PRIVMSG %s :\001DCC RESUME %s %d %d\001\r\n",
-					  dcc->nick, dcc->file, dcc->port, dcc->resumable);
+		snprintf (tbuf, sizeof (tbuf) - 10, strchr (dcc->file, ' ') ?
+					  "DCC RESUME \"%s\" %d %u" :
+					  "DCC RESUME %s %d %u",
+					  dcc->file, dcc->port, dcc->resumable);
+
+		if (dcc->pasvid)
+ 			sprintf (tbuf + strlen (tbuf), " %d", dcc->pasvid);
+
+		dcc->serv->p_ctcp (dcc->serv, dcc->nick, tbuf);
 	}
 }
 
@@ -1171,17 +1223,22 @@ void
 handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 				char *word_eol[])
 {
+	char tbuf[512];
 	struct DCC *dcc;
 	char *type = word[5];
-	int port, size;
-	unsigned long addr;
+	int port, pasvid = 0;
+	unsigned long size, addr;
 
 	if (!strcasecmp (type, "CHAT"))
 	{
 		port = atoi (word[8]);
 		sscanf (word[7], "%lu", &addr);
 
-		if (!addr || port < 1024)
+		if (port == 0)
+			pasvid = atoi (word[9]);
+
+		if (!addr || (port < 1024 && port != 0)
+			|| port > 0xffff || (port == 0 && pasvid == 0))
 		{
 			dcc_malformed (sess, nick, word_eol[4] + 2);
 			return;
@@ -1202,6 +1259,7 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 			dcc->dccstat = STAT_QUEUED;
 			dcc->addr = addr;
 			dcc->port = port;
+			dcc->pasvid = pasvid;
 			dcc->nick = strdup (nick);
 			dcc->starttime = time (0);
 
@@ -1224,19 +1282,21 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 			dcc = find_dcc (nick, word[6], TYPE_SEND);
 		if (dcc)
 		{
-			dcc->resumable = atoi (word[8]);
+			sscanf (word[8], "%lu", &size);
+			dcc->resumable = size;
 			if (dcc->resumable < dcc->size)
 			{
 				dcc->pos = dcc->resumable;
 				dcc->ack = dcc->resumable;
 				lseek (dcc->fp, dcc->pos, SEEK_SET);
 				/* filename contains spaces? */
-				tcp_sendf (dcc->serv, (strchr (file_part (dcc->file), ' ')) ?
-							"PRIVMSG %s :\001DCC ACCEPT \"%s\" %d %d\001\r\n" :
-							"PRIVMSG %s :\001DCC ACCEPT %s %d %d\001\r\n",
-							dcc->nick, file_part (dcc->file), port, dcc->resumable);
+				snprintf (tbuf, sizeof (tbuf), strchr (file_part (dcc->file), ' ') ?
+							"DCC ACCEPT \"%s\" %d %u" :
+							"DCC ACCEPT %s %d %u",
+							file_part (dcc->file), port, dcc->resumable);
+				dcc->serv->p_ctcp (dcc->serv, dcc->nick, tbuf);
 			}
-			sprintf (outbuf, "%d", dcc->pos);
+			sprintf (outbuf, "%u", dcc->pos);
 			EMIT_SIGNAL (XP_TE_DCCRESUMEREQUEST, sess, nick,
 							 file_part (dcc->file), outbuf, NULL, 0);
 		}
@@ -1256,11 +1316,15 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 	{
 		char *file = file_part (word[6]);
 		port = atoi (word[8]);
-		size = atoi (word[9]);
 
 		sscanf (word[7], "%lu", &addr);
+		sscanf (word[9], "%lu", &size);
 
-		if (!addr || !size || port < 1024)
+		if (port == 0)
+			pasvid = atoi (word[10]);
+
+		if (!addr || !size || (port < 1024 && port != 0)
+			|| port > 0xffff || (port == 0 && pasvid == 0))
 		{
 			dcc_malformed (sess, nick, word_eol[4] + 2);
 			return;
@@ -1281,7 +1345,18 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 				strcat (dcc->destfile, "/");
 			if (prefs.dccwithnick)
 			{
-				strcat (dcc->destfile, nick);
+#ifdef WIN32
+				char *t = strlen (dcc->destfile) + dcc->destfile;
+				strcpy (t, nick);
+				while (*t)
+				{
+					if (*t == '\\' || *t == '|')
+						*t = '_';
+					t++;
+				}
+#else
+ 				strcat (dcc->destfile, nick);
+#endif
 				strcat (dcc->destfile, ".");
 			}
 			strcat (dcc->destfile, file);
@@ -1299,6 +1374,7 @@ handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
 			dcc->dccstat = STAT_QUEUED;
 			dcc->addr = addr;
 			dcc->port = port;
+			dcc->pasvid = pasvid;
 			dcc->size = size;
 			dcc->nick = strdup (nick);
 			if (prefs.autodccsend)
@@ -1333,7 +1409,7 @@ dontresume:
 			else
 				fe_dcc_update_recv_win ();
 		}
-		sprintf (outbuf, "%d", size);
+		sprintf (outbuf, "%lu", size);
 		EMIT_SIGNAL (XP_TE_DCCSENDOFFER, sess->server->front_session, nick,
 						 file, outbuf, NULL, 0);
 	} else
@@ -1353,7 +1429,7 @@ dcc_show_list (struct session *sess, char *outbuf)
 	{
 		dcc = (struct DCC *) list->data;
 		i++;
-		PrintTextf (sess, " %s  %-10.10s %-7.7s %-7d %-7d %s\n",
+		PrintTextf (sess, " %s  %-10.10s %-7.7s %-7u %-7u %s\n",
 					 dcctypes[(int) dcc->type], dcc->nick,
 					 _(dccstat[(int) dcc->dccstat].name), dcc->size, dcc->pos,
 					 file_part (dcc->file));
