@@ -21,14 +21,15 @@ struct DCC
 	unsigned long addr;			/* the 32bit IP number, host byte order */
 	int fp;							/* file pointer */
 	int sok;
-	int iotag;
-	int wiotag;
+	int iotag;						/* reading io tag */
+	int wiotag;						/* writing/sending io tag */
 	int port;
+	int pasvid;						/* mIRC's passive DCC id */
 	int cps;
-	int size;
-	int resumable;
-	int ack;
-	int pos;
+	unsigned int size;
+	unsigned int resumable;
+	unsigned int ack;
+	unsigned int pos;
 	time_t starttime;
 	time_t offertime;
 	time_t lasttime;
