@@ -31,6 +31,7 @@ void fe_notify_update (char *name);
 void fe_text_clear (struct session *sess);
 void fe_close_window (struct session *sess);
 void fe_progressbar_start (struct session *sess);
+void fe_progressbar_destroy (struct session *sess);
 void fe_progressbar_end (struct server *serv);
 void fe_print_text (struct session *sess, char *text);
 void fe_userlist_insert (struct session *sess, struct User *newuser, int row, int sel);
@@ -49,7 +50,7 @@ void fe_dcc_open_chat_win (int passive);
 void fe_clear_channel (struct session *sess);
 void fe_session_callback (struct session *sess);
 void fe_server_callback (struct server *serv);
-void fe_checkurl (char *text);
+void fe_url_add (const char *text);
 void fe_pluginlist_update (void);
 void fe_buttons_update (struct session *sess);
 void fe_dlgbuttons_update (struct session *sess);
@@ -65,4 +66,4 @@ void fe_lastlog (session *sess, session *lastlog_sess, char *sstr);
 void fe_set_lag (server *serv, int lag);
 void fe_set_throttle (server *serv);
 void fe_set_away (server *serv);
-int fe_open_serverlist (session *sess, int auto_connect, int dont_show);
+void fe_serverlist_open (session *sess);
