@@ -102,7 +102,7 @@ find_session_from_nick (char *nick, server *serv)
 	session *sess;
 	GSList *list = sess_list;
 
-	sess = find_session_from_channel (nick, serv);
+	sess = find_dialog (serv, nick);
 	if (sess)
 		return sess;
 
@@ -136,7 +136,7 @@ inbound_privmsg (server *serv, char *tbuf, char *from, char *ip, char *text)
 {
 	session *sess;
 
-	sess = find_session_from_channel (from, serv);
+	sess = find_dialog (serv, from);
 
 	if (prefs.beepmsg || (sess && sess->beep))
 		fe_beep ();
@@ -225,21 +225,24 @@ inbound_action (session *sess, char *tbuf, char *chan, char *from, char *text,
 {
 	session *def = sess;
 	server *serv = sess->server;
-	int beep, is_chan = is_channel (serv, chan);
+	int beep = 0;
 
-	if (is_chan || fromme)
+	if (!fromme)
 	{
-		sess = find_session_from_channel (chan, serv);
-		beep = prefs.beepchans;
-	} else
-	{
-		/* it's a private action! */
-		beep = prefs.beepmsg;
-		/* find a dialog tab for it */
-		sess = find_session_from_channel (from, serv);
-		/* if non found, open a new one */
-		if (!sess && prefs.autodialog)
-			sess = new_ircwindow (serv, from, SESS_DIALOG);
+		if (is_channel (serv, chan))
+		{
+			sess = find_channel (serv, chan);
+			beep = prefs.beepchans;
+		} else
+		{
+			/* it's a private action! */
+			beep = prefs.beepmsg;
+			/* find a dialog tab for it */
+			sess = find_dialog (serv, from);
+			/* if non found, open a new one */
+			if (!sess && prefs.autodialog)
+				sess = new_ircwindow (serv, from, SESS_DIALOG);
+		}
 	}
 
 	if (!sess)
@@ -278,7 +281,9 @@ inbound_chanmsg (server *serv, char *tbuf, char *chan, char *from, char *text,
 	int hilight = FALSE;
 	char nickchar[2] = "\000";
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
+	if (!sess && !is_channel (serv, chan))
+		sess = find_dialog (serv, chan);
 	if (!sess)
 		return;
 
@@ -411,7 +416,7 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip)
 	session *sess;
 
 	/* already joined? probably a bnc */
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (!sess)
 	{
 		/* see if a window is waiting to join this channel */
@@ -458,7 +463,7 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip)
 void
 inbound_ukick (server *serv, char *chan, char *kicker, char *reason)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		EMIT_SIGNAL (XP_TE_UKICK, sess, serv->nick, chan, kicker, reason, 0);
@@ -474,7 +479,7 @@ inbound_ukick (server *serv, char *chan, char *kicker, char *reason)
 void
 inbound_upart (server *serv, char *chan, char *ip, char *reason)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		if (*reason)
@@ -493,7 +498,7 @@ inbound_nameslist (server *serv, char *chan, char *names)
 	char name[NICKLEN];
 	int pos = 0;
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (!sess)
 	{
 		EMIT_SIGNAL (XP_TE_USERSONCHAN, serv->server_session, chan, names, NULL,
@@ -538,7 +543,7 @@ inbound_topic (server *serv, char *chan, char *topic_text)
 	session *sess;
 	char *new_topic;
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (sess)
 	{
 		new_topic = strip_color (topic_text);
@@ -551,7 +556,7 @@ inbound_topic (server *serv, char *chan, char *topic_text)
 void
 inbound_topicnew (server *serv, char *nick, char *chan, char *topic)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		set_topic (sess, topic);
@@ -562,7 +567,7 @@ inbound_topicnew (server *serv, char *nick, char *chan, char *topic)
 void
 inbound_join (server *serv, char *chan, char *user, char *ip)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		if (!sess->hide_join_part)
@@ -574,7 +579,7 @@ inbound_join (server *serv, char *chan, char *user, char *ip)
 void
 inbound_kick (server *serv, char *chan, char *user, char *kicker, char *reason)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		EMIT_SIGNAL (XP_TE_KICK, sess, kicker, user, chan, reason, 0);
@@ -585,7 +590,7 @@ inbound_kick (server *serv, char *chan, char *user, char *kicker, char *reason)
 void
 inbound_part (server *serv, char *chan, char *user, char *ip, char *reason)
 {
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
 		if (!sess->hide_join_part)
@@ -603,7 +608,7 @@ void
 inbound_topictime (server *serv, char *chan, char *nick, time_t stamp)
 {
 	char *tim = ctime (&stamp);
-	session *sess = find_session_from_channel (chan, serv);
+	session *sess = find_channel (serv, chan);
 
 	tim[19] = 0;	/* get rid of the \n */
 	EMIT_SIGNAL (XP_TE_TOPICDATE, sess, chan, nick, tim, NULL, 0);
@@ -725,12 +730,12 @@ inbound_notice (server *serv, char *outbuf, char *to, char *nick, char *msg,
 	int server_notice = FALSE;
 
 	if (is_channel (serv, ptr))
-		sess = find_session_from_channel (ptr, serv);
+		sess = find_channel (serv, ptr);
 
 	if (!sess && ptr[0] == '@')
 	{
 		ptr++;
-		sess = find_session_from_channel (ptr, serv);
+		sess = find_channel (serv, ptr);
 	}
 
 	if (strcmp (nick, ip) == 0)
@@ -835,7 +840,7 @@ inbound_nameslist_end (server *serv, char *chan)
 		}
 		return TRUE;
 	}
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (sess)
 	{
 		sess->end_of_names = TRUE;
@@ -909,38 +914,21 @@ do_dns (session *sess, char *tbuf, char *nick, char *host)
 static void
 set_default_modes (server *serv)
 {
-	int mode = FALSE;
-	char outbuf[512];
+	char modes[8];
+
+	modes[0] = '+';
+	modes[1] = '\0';
 
 	if (prefs.wallops)
-	{
-		sprintf (outbuf, "MODE %s +w", serv->nick);
-		mode = TRUE;
-	}
+		strcat (modes, "w");
 	if (prefs.servernotice)
-	{
-		if (mode)
-			strcat (outbuf, "s");
-		else
-		{
-			sprintf (outbuf, "MODE %s +s", serv->nick);
-			mode = TRUE;
-		}
-	}
+		strcat (modes, "s");
 	if (prefs.invisible)
+		strcat (modes, "i");
+
+	if (modes[1] != '\0')
 	{
-		if (mode)
-			strcat (outbuf, "i");
-		else
-		{
-			sprintf (outbuf, "MODE %s +i", serv->nick);
-			mode = TRUE;
-		}
-	}
-	if (mode)
-	{
-		strcat (outbuf, "\r\n");
-		tcp_send (serv, outbuf);
+		serv->p_nick_mode (serv, serv->nick, modes);
 	}
 }
 
@@ -997,7 +985,7 @@ inbound_user_info (session *sess, char *outbuf, char *chan, char *user,
 	server *serv = sess->server;
 	session *who_sess;
 
-	who_sess = find_session_from_channel (chan, serv);
+	who_sess = find_channel (serv, chan);
 	if (who_sess)
 	{
 		sprintf (outbuf, "%s@%s", user, host);
@@ -1025,7 +1013,7 @@ inbound_banlist (session *sess, time_t stamp, char *chan, char *mask, char *bann
 	if (stamp == 0)
 		time_str = "";
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (!sess)
 		sess = serv->front_session;
    if (!fe_is_banwindow (sess))
