@@ -296,7 +296,7 @@ kanji_conv_to_locale(char *str)
 {
    static char *jpcode = NULL;
    static char *locale_euc[]  = { JCODE_LOCALE_EUC, NULL };
-   /*static char *locale_jis[]  = { JCODE_LOCALE_JIS, NULL };*/
+   static char *locale_jis[]  = { JCODE_LOCALE_JIS, NULL };
    static char *locale_sjis[] = { JCODE_LOCALE_SJIS, NULL };
 
    static struct LOCALE_TABLE {
