@@ -38,20 +38,22 @@ send_channel_modes (session *sess, char *tbuf, char *word[], int wpos,
 						  int end, char sign, char mode)
 {
 	int usable_modes, orig_len, len, wlen, i;
+	server *serv = sess->server;
 
 	/* sanity check. IRC RFC says three per line. */
-	if (sess->server->modes_per_line < 3)
-		sess->server->modes_per_line = 3;
+	if (serv->modes_per_line < 3)
+		serv->modes_per_line = 3;
 
 	while (wpos < end)
 	{
-		orig_len = len = sprintf (tbuf, "MODE %s ", sess->channel);
+		tbuf[0] = '\0';
+		orig_len = len = 0;
 
 		/* we'll need this many modechars too */
-		len += sess->server->modes_per_line;
+		len += serv->modes_per_line;
 
 		/* how many can we fit? */
-		for (i = 0; i < sess->server->modes_per_line; i++)
+		for (i = 0; i < serv->modes_per_line; i++)
 		{
 			/* no more nicks left? */
 			if (wpos + i >= end)
@@ -83,8 +85,7 @@ send_channel_modes (session *sess, char *tbuf, char *word[], int wpos,
 			strcat (tbuf, " ");
 			strcat (tbuf, word[wpos + i]);
 		}
-		strcat (tbuf, "\r\n");
-		tcp_send (sess->server, tbuf);
+		serv->p_chan_mode (serv, sess->channel, tbuf);
 
 		wpos += usable_modes;
 	}
@@ -209,7 +210,7 @@ mode_timeout_cb (session *sess)
 	if (is_session (sess))
 	{
 		sess->mode_timeout_tag = 0;
-		tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+		sess->server->p_join_info (sess->server, sess->channel);
 		sess->ignore_mode = TRUE;
 		sess->ignore_date = TRUE;
 	}
@@ -242,7 +243,7 @@ handle_single_mode (server * serv, char *outbuf, char sign, char mode,
 	outbuf[2] = mode;
 	outbuf[3] = 0;
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (!sess || !is_channel (serv, chan))
 	{
 		/* got modes for a chan we're not in! probably nickmode +isw etc */
@@ -436,7 +437,7 @@ handle_mode (server * serv, char *outbuf, char *word[], char *word_eol[],
 	if (*modes == 0)
 		return;	/* beyondirc's blank modes */
 
-	sess = find_session_from_channel (chan, serv);
+	sess = find_channel (serv, chan);
 	if (!sess)
 		sess = serv->front_session;
 	/* remove trailing space */
