@@ -174,7 +174,7 @@ notify_announce_online (server * serv, struct notify_per_server *servnot,
 	fe_notify_update (0);
 
 	if (prefs.whois_on_notifyonline)
-		tcp_sendf (serv, "WHOIS %s\r\n", nick);
+		serv->p_whois (serv, nick);
 }
 
 /* handles numeric 601 */
@@ -213,7 +213,7 @@ notify_watch (server * serv, char *nick, int add)
 	snprintf (tbuf, sizeof (tbuf), "WATCH +%s\r\n", nick);
 	if (!add)
 		tbuf[6] = '-';
-	tcp_send (serv, tbuf);
+	serv->p_raw (serv, tbuf);
 }
 
 static void
@@ -248,7 +248,7 @@ notify_flush_watches (server * serv, GSList *from, GSList *end)
 		list = list->next;
 	}
 	strcat (tbuf, "\r\n");
-	tcp_send (serv, tbuf);
+	serv->p_raw (serv, tbuf);
 }
 
 /* called when logging in. e.g. when End of motd. */
@@ -371,7 +371,7 @@ notify_checklist (void)
 		{
 			serv = (struct server *) list->data;
 			if (serv->connected && serv->end_of_motd && !serv->supports_watch)
-				tcp_send (serv, outbuf);
+				serv->p_raw (serv, outbuf);
 			list = list->next;
 		}
 	}
