@@ -445,6 +445,7 @@ ban (session * sess, char *tbuf, char *mask, char *bantypestr, int deop)
 	struct User *user;
 	char *at, *dot, *lastdot;
 	char username[64], fullhost[128], domain[128], *mode, *p2;
+	server *serv = sess->server;
 
 	user = find_name (sess, mask);
 	if (user && user->hostname)  /* it's a nickname, let's find a proper ban mask */
@@ -505,21 +506,19 @@ ban (session * sess, char *tbuf, char *mask, char *bantypestr, int deop)
 			switch (bantype)
 			{
 			case 0:
-				sprintf (tbuf, "MODE %s %s %s *!*@%s.*\r\n", sess->channel, mode, p2, domain);
+				sprintf (tbuf, "%s %s *!*@%s.*", mode, p2, domain);
 				break;
 
 			case 1:
-				sprintf (tbuf, "MODE %s %s %s *!*@%s\r\n", sess->channel, mode, p2, fullhost);
+				sprintf (tbuf, "%s %s *!*@%s", mode, p2, fullhost);
 				break;
 
 			case 2:
-				sprintf (tbuf, "MODE %s %s %s *!*%s@%s.*\r\n", sess->channel, mode, p2, 
-							username, domain);
+				sprintf (tbuf, "%s %s *!*%s@%s.*", mode, p2, username, domain);
 				break;
 
 			case 3:
-				sprintf (tbuf, "MODE %s %s %s *!*%s@%s\r\n", sess->channel, mode, p2, username,
-							fullhost);
+				sprintf (tbuf, "%s %s *!*%s@%s", mode, p2, username, fullhost);
 				break;
 			}
 		} else
@@ -527,30 +526,28 @@ ban (session * sess, char *tbuf, char *mask, char *bantypestr, int deop)
 			switch (bantype)
 			{
 			case 0:
-				sprintf (tbuf, "MODE %s %s %s *!*@*%s\r\n", sess->channel, mode, p2, domain);
+				sprintf (tbuf, "%s %s *!*@*%s", mode, p2, domain);
 				break;
 
 			case 1:
-				sprintf (tbuf, "MODE %s %s %s *!*@%s\r\n", sess->channel, mode, p2, fullhost);
+				sprintf (tbuf, "%s %s *!*@%s", mode, p2, fullhost);
 				break;
 
 			case 2:
-				sprintf (tbuf, "MODE %s %s %s *!*%s@*%s\r\n", sess->channel, mode, p2, username,
-							domain);
+				sprintf (tbuf, "%s %s *!*%s@*%s", mode, p2, username, domain);
 				break;
 
 			case 3:
-				sprintf (tbuf, "MODE %s %s %s *!*%s@%s\r\n", sess->channel, mode, p2, username,
-							fullhost);
+				sprintf (tbuf, "%s %s *!*%s@%s", mode, p2, username, fullhost);
 				break;
 			}
 		}
 
 	} else
 	{
-		sprintf (tbuf, "MODE %s +b %s\r\n", sess->channel, mask);
+		sprintf (tbuf, "+b %s", mask);
 	}
-	tcp_send (sess->server, tbuf);
+	serv->p_chan_mode (serv, sess->channel, tbuf);
 }
 
 static int
@@ -563,7 +560,7 @@ cmd_ban (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		ban (sess, tbuf, mask, word[3], 0);
 	} else
 	{
-		tcp_sendf (sess->server, "MODE %s +b\r\n", sess->channel);	/* banlist */
+		sess->server->p_chan_mode (sess->server, sess->channel, "+b");	/* banlist */
 	}
 
 	return TRUE;
@@ -1005,7 +1002,8 @@ cmd_devoice (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_discon (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	server_disconnect (sess, TRUE, -1);
+	sess->server->disconnect (sess, TRUE, -1);
+	sess->server->network = NULL;
 	return TRUE;
 }
 
@@ -1453,7 +1451,7 @@ cmd_flushq (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	sprintf (tbuf, "Flushing server send queue, %d bytes.\n", sess->server->sendq_len);
 	PrintText (sess, tbuf);
-	server_flush_queue (sess->server);
+	sess->server->flush_queue (sess->server);
 	return TRUE;
 }
 
@@ -1462,7 +1460,7 @@ cmd_quit (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	if (*word_eol[2])
 		sess->quitreason = word_eol[2];
-	server_disconnect (sess, TRUE, -1);
+	sess->server->disconnect (sess, TRUE, -1);
 	sess->quitreason = NULL;
 	return 2;
 }
@@ -1470,17 +1468,19 @@ cmd_quit (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_gate (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	char *server = word[2];
-	if (*server)
+	char *server_name = word[2];
+	server *serv = sess->server;
+	if (*server_name)
 	{
 		char *port = word[3];
 #ifdef USE_OPENSSL
-		sess->server->use_ssl = FALSE;
+		serv->use_ssl = FALSE;
 #endif
+		server_fill_her_up (serv);
 		if (*port)
-			server_connect (sess->server, server, atoi (port), TRUE);
+			serv->connect (serv, server_name, atoi (port), TRUE);
 		else
-			server_connect (sess->server, server, 23, TRUE);
+			serv->connect (serv, server_name, 23, TRUE);
 		return TRUE;
 	}
 	return FALSE;
@@ -1881,7 +1881,9 @@ cmd_msg (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 				}
 				sess->server->p_message (sess->server, nick, msg);
 			}
-			newsess = find_session_from_channel (nick, sess->server);
+			newsess = find_dialog (sess->server, nick);
+			if (!newsess)
+				newsess = find_channel (sess->server, nick);
 			if (newsess)
 				inbound_chanmsg (newsess->server, tbuf, newsess->channel,
 						newsess->server->nick, msg, TRUE);
@@ -1931,9 +1933,8 @@ cmd_nick (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	if (*nick)
 	{
 		if (sess->server->connected)
-		{
 			sess->server->p_change_nick (sess->server, nick);
-		} else
+		else
 			inbound_newnick (sess->server, sess->server->nick, nick, TRUE);
 		return TRUE;
 	}
@@ -2004,6 +2005,8 @@ cmd_part (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		chan = sess->channel;
 	if ((*chan) && is_channel (sess->server, chan))
 	{
+		if (reason[0] == 0)
+			reason = NULL;
 		server_sendpart (sess->server, chan, reason);
 		return TRUE;
 	}
@@ -2013,15 +2016,14 @@ cmd_part (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_ping (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
+	char timestring[64];
 	unsigned long tim;
 	char *to = word[2];
 
 	tim = make_ping_time ();
 
-	if (*to)
-		tcp_sendf (sess->server, "PRIVMSG %s :\001PING %lu\001\r\n", to, tim);
-	else
-		tcp_sendf (sess->server, "PING %lu\r\n", tim);
+	snprintf (timestring, sizeof (timestring), "%lu", tim);
+	sess->server->p_ping (sess->server, to, timestring);
 
 	return TRUE;
 }
@@ -2042,22 +2044,9 @@ cmd_query (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_quote (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	int len;
 	char *raw = word_eol[2];
-	if (*raw)
-	{
-		len = strlen (raw);
-		if (len < 4094)
-		{
-			tcp_send_len (sess->server, tbuf, sprintf (tbuf, "%s\r\n", raw));
-		} else
-		{
-			tcp_send_len (sess->server, raw, len);
-			tcp_send_len (sess->server, "\r\n", 2);
-		}
-		return TRUE;
-	}
-	return FALSE;
+
+	return sess->server->p_raw (sess->server, raw);
 }
 
 static int
@@ -2065,7 +2054,7 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	int tmp = prefs.recon_delay;
 	GSList *list;
-	server *serv;
+	server *serv = sess->server;
 
 	prefs.recon_delay = 0;
 
@@ -2076,7 +2065,7 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		{
 			serv = list->data;
 			if (serv->connected)
-				auto_reconnect (serv, TRUE, -1);
+				serv->auto_reconnect (serv, TRUE, -1);
 			list = list->next;
 		}
 	}	
@@ -2093,20 +2082,20 @@ cmd_reconnect (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			use_ssl = TRUE;
 			offset++;	/* args move up by 1 word */
 		}
-		sess->server->use_ssl = use_ssl;
-		sess->server->accept_invalid_cert = TRUE;
+		serv->use_ssl = use_ssl;
+		serv->accept_invalid_cert = TRUE;
 #endif
 
 		if (*word[4+offset])
-			safe_strcpy (sess->server->password, word[4+offset], sizeof (sess->server->password));
+			safe_strcpy (serv->password, word[4+offset], sizeof (serv->password));
 		if (*word[3+offset])
-			sess->server->port = atoi (word[3+offset]);
-		safe_strcpy (sess->server->hostname, word[2+offset], sizeof (sess->server->hostname));
-		auto_reconnect (sess->server, TRUE, -1);
+			serv->port = atoi (word[3+offset]);
+		safe_strcpy (serv->hostname, word[2+offset], sizeof (serv->hostname));
+		serv->auto_reconnect (serv, TRUE, -1);
 	}
 	else
 	{
-		auto_reconnect (sess->server, TRUE, -1);
+		serv->auto_reconnect (serv, TRUE, -1);
 	}	
 	prefs.recon_delay = tmp;
 
@@ -2155,10 +2144,11 @@ static int
 cmd_server (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	int offset = 0;
-	char *server;
+	char *server_name;
 	char *port;
 	char *pass;
 	char *co;
+	server *serv = sess->server;
 #ifdef USE_OPENSSL
 	int use_ssl = FALSE;
 
@@ -2169,18 +2159,18 @@ cmd_server (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	}
 #endif
 
-	server = word[2 + offset];
+	server_name = word[2 + offset];
 	port = word[3 + offset];
 	pass = word[4 + offset];
 
-	if (!(*server))
+	if (!(*server_name))
 		return FALSE;
 
 #ifdef USE_OPENSSL
-	if (strncasecmp ("ircs://", server, 7) == 0)
+	if (strncasecmp ("ircs://", server_name, 7) == 0)
 	{
 		use_ssl = TRUE;
-		server += 7;
+		server_name += 7;
 		goto urlserv;
 	}
 #endif
@@ -2189,21 +2179,21 @@ cmd_server (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	if (strncasecmp (word_eol[1], "SERVCHAN ", 9))
 		sess->willjoinchannel[0] = 0;
 
-	if (strncasecmp ("irc://", server, 6) == 0)
+	if (strncasecmp ("irc://", server_name, 6) == 0)
 	{
-		server += 6;
+		server_name += 6;
 #ifdef USE_OPENSSL
 urlserv:
 #endif
 		/* check for port */
-		co = strchr (server, ':');
+		co = strchr (server_name, ':');
 		if (co)
 		{
 			port = co + 1;
 			*co = 0;
 			pass = word[3 + offset];
 		} else
-			co = server;
+			co = server_name;
 		/* check for channel - mirc style */
 		co = strchr (co + 1, '/');
 		if (co)
@@ -2223,24 +2213,20 @@ urlserv:
 
 	if (*pass)
 	{
-		safe_strcpy (sess->server->password, pass, sizeof (sess->server->password));
+		safe_strcpy (serv->password, pass, sizeof (serv->password));
 	}
 #ifdef USE_OPENSSL
-	sess->server->use_ssl = use_ssl;
-	sess->server->accept_invalid_cert = TRUE;
+	serv->use_ssl = use_ssl;
+	serv->accept_invalid_cert = TRUE;
 #endif
 
 	if (*port)
 	{
-		server_connect (sess->server, server, atoi (port), FALSE);
+		serv->connect (serv, server_name, atoi (port), FALSE);
 	} else
 	{
-#ifdef USE_OPENSSL
-		if (use_ssl)
-			server_connect (sess->server, server, 9999, FALSE);
-		else
-#endif
-			server_connect (sess->server, server, 6667, FALSE);
+		/* -1 for default port */
+		serv->connect (serv, server_name, -1, FALSE);
 	}
 	return TRUE;
 }
@@ -2373,7 +2359,7 @@ cmd_wallchop (struct session *sess, char *tbuf, char *word[],
 				i = 0;
 				sprintf (tbuf + strlen (tbuf),
 							" :[@%s] %s\r\n", sess->channel, word_eol[2]);
-				tcp_send (sess->server, tbuf);
+				sess->server->p_raw (sess->server, tbuf);
 				strcpy (tbuf, "NOTICE ");
 			}
 			list = list->next;
@@ -3069,7 +3055,8 @@ handle_command (session *sess, char *cmd, int check_spch)
 		PrintText (sess, _("Unknown Command. Try /help\n"));
 		goto xit;
 	}
-	tcp_sendf (sess->server, "%s\r\n", cmd);
+	snprintf (tbuf, sizeof (tbuf), "%s\r\n", cmd);
+	sess->server->p_raw (sess->server, tbuf);
 
 xit:
 	command_level--;
