@@ -570,8 +570,9 @@ xchat_unhook (xchat_plugin *ph, xchat_hook *hook)
 {
 	void *userdata;
 
-/*	if (!g_slist_find (hook_list, hook))
-		return NULL;*/
+	/* perl.c trips this */
+	if (!g_slist_find (hook_list, hook))
+		return NULL;
 
 	if (hook->type == HOOK_TIMER && hook->tag != 0)
 		fe_timeout_remove (hook->tag);
@@ -836,9 +837,12 @@ xchat_list_get (xchat_plugin *ph, const char *name)
 		break;
 
 	case 0x6a68e08: /* users */
-		list->type = LIST_USERS;
-		list->next = ph->context->userlist;
-		break;
+		if (is_session (ph->context))
+		{
+			list->type = LIST_USERS;
+			list->next = ph->context->userlist;
+			break;
+		}	/* fall through */
 
 	default:
 		free (list);
