@@ -132,6 +132,18 @@ irc_invite (server *serv, char *channel, char *nick)
 	tcp_sendf (serv, "INVITE %s %s\r\n", nick, channel);
 }
 
+static void
+irc_chan_mode (server *serv, char *channel, char *mode)
+{
+	tcp_sendf (serv, "MODE %s %s\r\n", channel, mode);
+}
+
+static void
+irc_nick_mode (server *serv, char *nick, char *mode)
+{
+	tcp_sendf (serv, "MODE %s %s\r\n", nick, mode);
+}
+
 /* find channel info when joined */
 
 static void
@@ -154,6 +166,17 @@ irc_get_ip (server *serv, char *nick)
 	tcp_sendf (serv, "WHO %s\r\n", nick);
 }*/
 
+
+/*
+ *  Command: WHOIS
+ *     Parameters: [<server>] <nickmask>[,<nickmask>[,...]]
+ */
+static void
+irc_user_whois (server *serv, char *nicks)
+{
+	tcp_sendf (serv, "WHOIS %s\r\n", nicks);
+}
+
 static void
 irc_message (server *serv, char *channel, char *text)
 {
@@ -209,6 +232,36 @@ irc_change_nick (server *serv, char *new_nick)
 	tcp_sendf (serv, "NICK %s\r\n", new_nick);
 }
 
+static void
+irc_ping (server *serv, char *to, char *timestring)
+{
+	if (*to)
+		tcp_sendf (serv, "PRIVMSG %s :\001PING %s\001\r\n", to, timestring);
+	else
+		tcp_sendf (serv, "PING %s\r\n", timestring);
+}
+
+static int
+irc_raw (server *serv, char *raw)
+{
+	int len;
+	char tbuf[4096];
+	if (*raw)
+	{
+		len = strlen (raw);
+		if (len < sizeof (tbuf) - 3)
+		{
+			len = snprintf (tbuf, sizeof (tbuf), "%s\r\n", raw);
+			tcp_send_len (serv, tbuf, len);
+		} else
+		{
+			tcp_send_len (serv, raw, len);
+			tcp_send_len (serv, "\r\n", 2);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
 
 /* ============================================================== */
 /* ======================= IRC INPUT ============================ */
@@ -341,7 +394,7 @@ process_numeric (session * sess, char *outbuf, int n,
 		break;
 
 	case 324:
-		sess = find_session_from_channel (word[4], serv);
+		sess = find_channel (serv, word[4]);
 		if (!sess)
 			sess = serv->server_session;
 		if (sess->ignore_mode)
@@ -361,7 +414,7 @@ process_numeric (session * sess, char *outbuf, int n,
 		break;
 
 	case 329:
-		sess = find_session_from_channel (word[4], serv);
+		sess = find_channel (serv, word[4]);
 		if (sess)
 		{
 			if (sess->ignore_date)
@@ -405,7 +458,7 @@ process_numeric (session * sess, char *outbuf, int n,
 		} else
 		{
 			session *who_sess;
-			who_sess = find_session_from_channel (word[4], serv);
+			who_sess = find_channel (serv, word[4]);
 			if (who_sess)
 			{
 				if (!who_sess->doing_who)
@@ -435,7 +488,7 @@ process_numeric (session * sess, char *outbuf, int n,
 		break;
 
 	case 368:
-		sess = find_session_from_channel (word[4], serv);
+		sess = find_channel (serv, word[4]);
 		if (!sess)
 			sess = serv->front_session;
 		if (!fe_is_banwindow (sess))
@@ -500,7 +553,7 @@ process_numeric (session * sess, char *outbuf, int n,
 	def:
 		if (is_channel (serv, word[4]))
 		{
-			realsess = find_session_from_channel (word[4], serv);
+			realsess = find_channel (serv, word[4]);
 			if (!realsess)
 				realsess = sess;
 			EMIT_SIGNAL (XP_TE_SERVTEXT, realsess, text, word[1], NULL, NULL, 0);
@@ -729,7 +782,7 @@ irc_inline (server *serv, char *buf)
 		/* find a context for this message */
 		if (is_channel (serv, word[3]))
 		{
-			tmp = find_session_from_channel (word[3], serv);
+			tmp = find_channel (serv, word[3]);
 			if (tmp)
 				sess = tmp;
 		}
@@ -780,8 +833,11 @@ proto_fill_her_up (server *serv)
 	serv->p_join = irc_join;
 	serv->p_login = irc_login;
 	serv->p_join_info = irc_join_info;
+	serv->p_chan_mode = irc_chan_mode;
+	serv->p_nick_mode = irc_nick_mode;
 	serv->p_user_list = irc_user_list;
 	/*serv->p_get_ip = irc_get_ip;*/
+	serv->p_whois = irc_user_whois;
 	serv->p_get_ip = irc_user_list;
 	serv->p_set_back = irc_set_back;
 	serv->p_set_away = irc_set_away;
@@ -792,4 +848,6 @@ proto_fill_her_up (server *serv)
 	serv->p_list_channels = irc_list_channels;
 	serv->p_change_nick = irc_change_nick;
 	serv->p_names = irc_names;
+	serv->p_ping = irc_ping;
+	serv->p_raw = irc_raw;
 }
