@@ -44,6 +44,9 @@
 #include "outbound.h"
 #include "text.h"
 #include "util.h"
+#include "url.h"
+#include "proto-irc.h"
+#include "servlist.h"
 #include "server.h"
 
 #ifdef USE_OPENSSL
@@ -66,6 +69,10 @@ extern SSL_CTX *ctx;				  /* xchat.c */
 static struct session *g_sess = NULL;
 #endif
 
+static void auto_reconnect (server *serv, int send_quit, int err);
+static void server_disconnect (session * sess, int sendquit, int err);
+static int server_cleanup (server * serv);
+static void server_connect (server *serv, char *hostname, int port, int no_login);
 
 static int
 tcp_send_real_real (server *serv, char *buf, int len)
@@ -74,7 +81,14 @@ tcp_send_real_real (server *serv, char *buf, int len)
 	char *locale = NULL;
 
 	if (!serv->use_utf8)
-		locale = g_locale_from_utf8 (buf, len, NULL, &len, NULL);
+	{
+		int loc_len;
+
+		locale = g_locale_from_utf8 (buf, len, NULL, &loc_len, NULL);
+		if (locale)
+			len = loc_len;
+	}
+
 	if (locale)
 	{
 #ifdef USE_OPENSSL
@@ -307,7 +321,7 @@ server_inline (server *serv, char *line)
 	if (utf)
 	{
 		fe_add_rawlog (serv, utf, FALSE);
-		fe_checkurl (utf);
+		url_check (utf);
 
 		/* let proto-irc.c handle it */
 		serv->p_inline (serv, utf);
@@ -316,7 +330,7 @@ server_inline (server *serv, char *line)
 	} else
 	{
 		fe_add_rawlog (serv, line, FALSE);
-		fe_checkurl (line);
+		url_check (line);
 
 		/* let proto-irc.c handle it */
 		serv->p_inline (serv, line);
@@ -457,8 +471,8 @@ server_stopconnecting (server * serv)
 	kill (serv->childpid, SIGKILL);
 	waitpid (serv->childpid, NULL, 0);
 #else
-	TerminateThread ((HANDLE)serv->childpid, 0);
-	CloseHandle ((HANDLE)serv->childpid);
+	PostThreadMessage (serv->childpid, WM_QUIT, 0, 0);
+	CloseHandle ((HANDLE)serv->childhandle);
 #endif
 
 	close (serv->childwrite);
@@ -683,7 +697,7 @@ timeout_auto_reconnect (server *serv)
 	return 0;			  /* returning 0 should remove the timeout handler */
 }
 
-void
+static void
 auto_reconnect (server *serv, int send_quit, int err)
 {
 	session *s;
@@ -725,7 +739,7 @@ auto_reconnect (server *serv, int send_quit, int err)
 	serv->recondelay_tag = fe_timeout_add (del, timeout_auto_reconnect, serv);
 }
 
-void
+static void
 server_flush_queue (server *serv)
 {
 	list_free (&serv->outbound_queue);
@@ -819,8 +833,9 @@ server_read_child (GIOChannel *source, GIOCondition condition, server *serv)
 			closesocket (serv->sok6);
 #endif
 		EMIT_SIGNAL (XP_TE_UKNHOST, sess, NULL, NULL, NULL, NULL, 0);
-		if (prefs.autoreconnectonfail)
-			auto_reconnect (serv, FALSE, -1);
+		if (!servlist_cycle (serv))
+			if (prefs.autoreconnectonfail)
+				auto_reconnect (serv, FALSE, -1);
 		break;
 	case '2':						  /* connection failed */
 		waitline2 (source, tbuf, sizeof tbuf);
@@ -832,8 +847,9 @@ server_read_child (GIOChannel *source, GIOCondition condition, server *serv)
 #endif
 		EMIT_SIGNAL (XP_TE_CONNFAIL, sess, errorstring (atoi (tbuf)), NULL,
 						 NULL, NULL, 0);
-		if (prefs.autoreconnectonfail)
-			auto_reconnect (serv, FALSE, -1);
+		if (!servlist_cycle (serv))
+			if (prefs.autoreconnectonfail)
+				auto_reconnect (serv, FALSE, -1);
 		break;
 	case '3':						  /* gethostbyname finished */
 		waitline2 (source, host, sizeof host);
@@ -879,7 +895,7 @@ server_read_child (GIOChannel *source, GIOCondition condition, server *serv)
 /* kill all sockets & iotags of a server. Stop a connection attempt, or
    disconnect if already connected. */
 
-int
+static int
 server_cleanup (server * serv)
 {
 	fe_set_lag (serv, 0.0);
@@ -925,7 +941,7 @@ server_cleanup (server * serv)
 	return 0;
 }
 
-void
+static void
 server_disconnect (session * sess, int sendquit, int err)
 {
 	server *serv = sess->server;
@@ -1257,20 +1273,42 @@ xit:
 		free (ip);
 	if (real_hostname)
 		free (real_hostname);
+	fclose (fd);
 #endif
 
 	return 0;
 }
 
-void
+static void
 server_connect (server *serv, char *hostname, int port, int no_login)
 {
 	int pid, read_des[2];
 	session *sess;
 
+#ifdef USE_OPENSSL
+	if (!ctx && serv->use_ssl)
+	{
+		if (!(ctx = _SSL_context_init (ssl_cb_info, FALSE)))
+		{
+			fprintf (stderr, "_SSL_context_init failed\n");
+			exit (1);
+		}
+	}
+#endif
+
 	if (!hostname[0])
 		return;
 
+	if (port < 0 || port >= 65536)
+	{
+		/* use default port for this server type */
+		port = 6667;
+#ifdef USE_SSL
+		if (serv->use_ssl)
+			port = 9999;
+#endif
+	}
+
 	sess = serv->server_session;
 
 	if (serv->connected || serv->connecting || serv->recondelay_tag)
@@ -1305,8 +1343,9 @@ server_connect (server *serv, char *hostname, int port, int no_login)
 	net_sockets (&serv->sok4, &serv->sok6);
 
 #ifdef WIN32
-	pid = (int)CreateThread (NULL, 0, (LPTHREAD_START_ROUTINE)server_child,
-									 serv, 0, (DWORD *)&pid);
+	serv->childhandle = (int)CreateThread (NULL, 0,
+													(LPTHREAD_START_ROUTINE)server_child,
+													serv, 0, (DWORD *)&pid);
 #else
 	switch (pid = fork ())
 	{
@@ -1325,3 +1364,14 @@ server_connect (server *serv, char *hostname, int port, int no_login)
 	serv->iotag =
 		fe_input_add (serv->childread, 3, 0, 0, server_read_child, serv);
 }
+
+void server_fill_her_up (server *serv)
+{
+	serv->connect = server_connect;
+	serv->disconnect = server_disconnect;
+	serv->cleanup = server_cleanup;
+	serv->flush_queue = server_flush_queue;
+	serv->auto_reconnect = auto_reconnect;
+
+	proto_fill_her_up (serv);
+}
