@@ -989,7 +989,7 @@ pevent_load (char *filename)
 
 	fd = open (buf, O_RDONLY | OFLAGS);
 	free (buf);
-	if (fd < 0)
+	if (fd == -1)
 		return 1;
 	if (fstat (fd, &st) != 0)
 		return 1;
@@ -1111,12 +1111,13 @@ display_event (char *i, session *sess, int numargs, char **args)
 			ar = args[(int) a + 1];
 			if (ar == NULL)
 			{
-				printf ("Error args[a] == NULL in display_event\n");
-				abort ();
+				printf ("arg[%d] is NULL in print event\n", a + 1);
+			} else
+			{
+				len = strlen (ar);
+				memcpy (&o[oi], ar, len);
+				oi += len;
 			}
-			len = strlen (ar);
-			memcpy (&o[oi], ar, len);
-			oi += len;
 			break;
 		case 2:
 			o[oi++] = '\n';
@@ -1376,7 +1377,7 @@ pevent_save (char *fn)
 	else
 		safe_strcpy (buf, fn, sizeof (buf));
 	fd = open (buf, O_CREAT | O_TRUNC | O_WRONLY | OFLAGS, 0x180);
-	if (fd < 0)
+	if (fd == -1)
 	{
 		/*
 		   fe_message ("Error opening config file\n", FALSE); 
