@@ -9,7 +9,7 @@ struct User
 	time_t lasttalk;
 	int weight;
 	unsigned int access;	/* axs bit field */
-	char prefix; /* @ + % */
+	char prefix[2]; /* @ + % */
 	unsigned int admin:1;
 	unsigned int op:1;
 	unsigned int hop:1;
@@ -26,7 +26,6 @@ struct User *find_name_global (struct server *serv, char *name);
 void update_user_list (struct session *sess);
 void clear_user_list (struct session *sess);
 void free_userlist (struct session *sess);
-void sort_namelist (struct session *sess);
 void add_name (struct session *sess, char *name, char *hostname);
 int sub_name (struct session *sess, char *name);
 void change_nick (struct session *sess, char *oldname, char *newname);
