@@ -266,7 +266,7 @@ nocasestrstr (char *s, char *wanted)
 
 	if (len == 0)
 		return (char *)s;
-	while (tolower(*s) != tolower(*wanted) || strncasecmp (s, wanted, len))
+	while (rfc_tolower(*s) != rfc_tolower(*wanted) || strncasecmp (s, wanted, len))
 		if (*s++ == '\0')
 			return (char *)NULL;
 	return (char *)s;
@@ -393,22 +393,6 @@ strip_color (unsigned char *text)
 	return new_str;
 }
 
-char *
-strip_spaces (char *buf)
-{
-	char *s = buf;
-	size_t len = strlen (buf) + 1;
-	size_t ofs;
-
-	while (s[ofs = strcspn (s, " \t")])
-	{
-		size_t cnt = strspn (s+= ofs, " \t");
-		memmove (s, s + cnt, len-= ofs + cnt);
-	}
-
-	return buf;
-}
-
 #if defined (USING_LINUX) || defined (USING_FREEBSD)
 
 static void
@@ -590,7 +574,7 @@ int match(const char *mask, const char *string)
 	if (*m == '?' || *m == '*')
 	  ch = *m++;
       default:
-	if (tolower(*s) != tolower(ch))
+	if (rfc_tolower(*s) != rfc_tolower(ch))
 	  return 0;
       case '?':
 	if (!*s++)
@@ -620,8 +604,8 @@ got_star:
 break_while:
   if (!ch)
     return 1;			/* mask ends with '*', we got it */
-  ch = tolower(ch);
-  while (tolower(*s++) != ch)
+  ch = rfc_tolower(ch);
+  while (rfc_tolower(*s++) != ch)
     if (!*s)
       return 0;
   bs = s;			/* Next try start from here */
@@ -637,7 +621,7 @@ break_while:
 	if (*m == '?' || *m == '*')
 	  ch = *m++;
       default:
-	if (tolower(*s) != tolower(ch))
+	if (rfc_tolower(*s) != rfc_tolower(ch))
 	{
 	  m = bm;
 	  s = bs;
@@ -657,13 +641,12 @@ break_while:
   return 1;
 }
 
-int
+void
 for_files (char *dirname, char *mask, void callback (char *file))
 {
 	DIR *dir;
 	struct dirent *ent;
 	char *buf;
-	int i = 0;
 
 	dir = opendir (dirname);
 	if (dir)
@@ -674,7 +657,6 @@ for_files (char *dirname, char *mask, void callback (char *file))
 			{
 				if (match (mask, ent->d_name))
 				{
-					i++;
 					buf = malloc (strlen (dirname) + strlen (ent->d_name) + 2);
 					sprintf (buf, "%s/%s", dirname, ent->d_name);
 					callback (buf);
@@ -684,7 +666,6 @@ for_files (char *dirname, char *mask, void callback (char *file))
 		}
 		closedir (dir);
 	}
-	return i;
 }
 
 void
@@ -692,7 +673,7 @@ tolowerStr (char *str)
 {
 	while (*str)
 	{
-		*str = tolower (*str);
+		*str = rfc_tolower (*str);
 		str++;
 	}
 }
@@ -1138,7 +1119,7 @@ rfc_casecmp (char *s1, char *s2)
 	register unsigned char *str2 = (unsigned char *) s2;
 	register int res;
 
-	while ((res = tolower (*str1) - tolower (*str2)) == 0)
+	while ((res = rfc_tolower (*str1) - rfc_tolower (*str2)) == 0)
 	{
 		if (*str1 == '\0')
 			return 0;
@@ -1155,7 +1136,7 @@ rfc_ncasecmp (char *str1, char *str2, int n)
 	register unsigned char *s2 = (unsigned char *) str2;
 	register int res;
 
-	while ((res = tolower (*s1) - tolower (*s2)) == 0)
+	while ((res = rfc_tolower (*s1) - rfc_tolower (*s2)) == 0)
 	{
 		s1++;
 		s2++;
@@ -1166,7 +1147,7 @@ rfc_ncasecmp (char *str1, char *str2, int n)
 	return (res);
 }
 
-const unsigned char tolowertab[] =
+const unsigned char rfc_tolowertab[] =
 	{ 0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa,
 	0xb, 0xc, 0xd, 0xe, 0xf, 0x10, 0x11, 0x12, 0x13, 0x14,
 	0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d,
