@@ -11,17 +11,16 @@
  *        --+ Dagmar d'Surreal
  */
 
-#undef tolower
-#define tolower(c) (tolowertab[(unsigned char)(c)])
+#define rfc_tolower(c) (rfc_tolowertab[(unsigned char)(c)])
 
-extern const unsigned char tolowertab[];
+extern const unsigned char rfc_tolowertab[];
 
 int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr);
 char *expand_homedir (char *file);
 void path_part (char *file, char *path, int pathlen);
 int match (const char *mask, const char *string);
 char *file_part (char *file);
-int for_files (char *dirname, char *mask, void callback (char *file));
+void for_files (char *dirname, char *mask, void callback (char *file));
 int rfc_casecmp (char *, char *);
 int rfc_ncasecmp (char *, char *, int);
 void tolowerStr (char *str);
@@ -31,7 +30,6 @@ char *country (char *);
 char *get_cpu_str (void);
 int util_exec (char *cmd);
 unsigned char *strip_color (unsigned char *text);
-char *strip_spaces (char *buf);
 char *errorstring (int err);
 int waitline (int sok, char *buf, int bufsize);
 unsigned long make_ping_time (void);
