@@ -40,9 +40,10 @@
 #include "plugin.h"
 #include "notify.h"
 #include "server.h"
+#include "servlist.h"
 #include "outbound.h"
 #include "text.h"
-#include "proto-irc.h"
+#include "url.h"
 #include "plugin-timer.h"
 #include "xchatc.h"
 
@@ -112,14 +113,14 @@ find_dialog (server *serv, char *nick)
 }
 
 session *
-find_session_from_channel (char *chan, server *serv)
+find_channel (server *serv, char *chan)
 {
 	session *sess;
 	GSList *list = sess_list;
 	while (list)
 	{
 		sess = list->data;
-		if (!serv || serv == sess->server)
+		if ((!serv || serv == sess->server) && sess->type != SESS_DIALOG)
 		{
 			if (!rfc_casecmp (chan, sess->channel))
 				return sess;
@@ -171,10 +172,11 @@ lag_check (void)
 				sprintf (tbuf, "%d", lag);
 				EMIT_SIGNAL (XP_TE_PINGTIMEOUT, serv->server_session, tbuf, NULL,
 								 NULL, NULL, 0);
-				auto_reconnect (serv, FALSE, -1);
+				serv->auto_reconnect (serv, FALSE, -1);
 			} else
 			{
-				tcp_sendf (serv, "PING LAG%lu\r\n", tim);
+				snprintf (tbuf, sizeof (tbuf), "LAG%lu", tim);
+				serv->p_ping (serv, "", tbuf);
 				serv->lag_sent = tim;
 				fe_set_lag (serv, -1);
 			}
@@ -291,8 +293,8 @@ new_server (void)
 	serv = malloc (sizeof (struct server));
 	memset (serv, 0, sizeof (struct server));
 
-	/* use proto-irc.c functions */
-	proto_fill_her_up (serv);
+	/* use server.c and proto-irc.c functions */
+	server_fill_her_up (serv);
 
 	serv->sok = -1;
 	strcpy (serv->nick, prefs.nick1);
@@ -320,13 +322,12 @@ new_ircwindow (server *serv, char *name, int type)
 			prefs.hideuserlist = 1;
 			sess = new_session (serv, name, SESS_SERVER);
 			prefs.hideuserlist = oldh;
-
-			serv->server_session = sess;
-			serv->front_session = sess;
 		} else
 		{
 			sess = new_session (serv, name, SESS_CHANNEL);
 		}
+		serv->server_session = sess;
+		serv->front_session = sess;
 		break;
 	default:
 /*	case SESS_CHANNEL:
@@ -392,14 +393,14 @@ save_away_message (struct server *serv, char *nick, char *msg)
 static void
 kill_server_callback (server * serv)
 {
-	server_cleanup (serv);
+	serv->cleanup (serv);
 
 /*	fe_server_callback (serv);*/
 
 	serv_list = g_slist_remove (serv_list, serv);
 
 	dcc_notify_kill (serv);
-	server_flush_queue (serv);
+	serv->flush_queue (serv);
 	free_away_messages (serv);
 
 	free (serv->nick_modes);
@@ -468,7 +469,7 @@ send_quit_or_part (session * killsess)
 		{
 			if (!killserv->sent_quit)
 			{
-				server_flush_queue (killserv);
+				killserv->flush_queue (killserv);
 				server_sendquit (killsess);
 				killserv->sent_quit = TRUE;
 			}
@@ -489,6 +490,8 @@ kill_session_callback (session * killsess)
 	session *sess;
 	GSList *list;
 
+	plugin_emit_dummy_print (killsess, "Close Context");
+
 	if (current_tab == killsess)
 		current_tab = NULL;
 
@@ -514,6 +517,9 @@ kill_session_callback (session * killsess)
 		}
 	}
 
+	if (!killserv->server_session)
+		killserv->server_session = killserv->front_session;
+
 	sess_list = g_slist_remove (sess_list, killsess);
 
 	if (killsess->type == SESS_CHANNEL)
@@ -523,10 +529,6 @@ kill_session_callback (session * killsess)
 
 	exec_notify_kill (killsess);
 
-/*#ifdef USE_PERL
-	perl_notify_kill (killsess);
-#endif*/
-
 	log_close (killsess);
 
 	send_quit_or_part (killsess);
@@ -735,6 +737,7 @@ find_away_message (struct server *serv, char *nick)
 	"NAME SUB\n"								"CMD Mozilla...\n\n"\
 		"NAME Open in existing\n"			"CMD !mozilla -remote 'openURL(%s)'\n\n"\
 		"NAME Open in new window\n"		"CMD !mozilla -remote 'openURL(%s,new-window)'\n\n"\
+		"NAME Open in new tab\n"			"CMD !mozilla -remote 'openURL(%s,new-tab)'\n\n"\
 		"NAME Run new Mozilla\n"			"CMD !mozilla %s\n\n"\
 	"NAME ENDSUB\n"							"CMD \n\n"\
 	"NAME SUB\n"								"CMD Galeon...\n\n"\
@@ -762,6 +765,28 @@ find_away_message (struct server *serv, char *nick)
 	"NAME Connect as IRC server\n"		"CMD newserver %s\n\n"
 #endif
 
+#ifndef WIN32
+/* Close and open log files on SIGUSR1. Usefull for log rotating */
+
+static void 
+sighup_handler (int signal)
+{
+	GSList *list = sess_list;
+	session *sess;
+
+	if (prefs.logging)
+	{
+		while (list)
+		{
+			sess = list->data;
+			log_open (sess);
+			list = list->next;
+		}
+	}
+}
+
+#endif
+
 static void
 xchat_init (void)
 {
@@ -777,6 +802,9 @@ xchat_init (void)
 	act.sa_flags = 0;
 	sigemptyset (&act.sa_mask);
 	sigaction (SIGPIPE, &act, NULL);
+
+	/* Deal with SIGUSR1's */
+	signal (SIGUSR1, sighup_handler);
 #endif
 
 	load_text_events ();
@@ -800,15 +828,18 @@ xchat_init (void)
 	}
 #endif
 
-	/* if serverlist didnt open any irc windows .... */
-	if (!fe_open_serverlist (NULL, auto_connect, prefs.skipserverlist))
+	servlist_init ();							/* load server list */
+
+	if (!prefs.slist_skip)
+		fe_serverlist_open (NULL);
+
+	/* do any auto connects */
+	if (!servlist_auto_connect (NULL))	/* if no new windows open .. */
 	{
-		/* and serverlist isn't open .... */
-		if (prefs.skipserverlist)
-		{
+		/* and no serverlist gui ... */
+		if (prefs.slist_skip)
 			/* we'll have to open one. */
 			new_ircwindow (NULL, NULL, SESS_SERVER);
-		}
 	}
 }
 
@@ -824,6 +855,8 @@ xchat_exit (void)
 		save_config ();
 		pevent_save (NULL);
 	}
+	if (prefs.autosave_url)
+		url_autosave ();
 	notify_save ();
 	ignore_save ();
 	free_sessions ();
@@ -864,14 +897,6 @@ main (int argc, char *argv[])
 	SOCKSinit (argv[0]);
 #endif
 
-#ifdef USE_OPENSSL
-	if (!(ctx = _SSL_context_init (ssl_cb_info, FALSE)))
-	{
-		fprintf (stderr, "_SSL_context_init failed\n");
-		return 1;
-	}
-#endif
-
 	if (!fe_args (argc, argv))
 		return 0;
 
@@ -884,7 +909,8 @@ main (int argc, char *argv[])
 	fe_main ();
 
 #ifdef USE_OPENSSL
-	_SSL_context_free (ctx);
+	if (ctx)
+		_SSL_context_free (ctx);
 #endif
 
 #ifdef USE_DEBUG
