@@ -53,7 +53,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	char buf[512];
 	const gchar *author[] = { "Peter Zelezny <zed@xchat.org>", 0 };
 
-	snprintf (buf, sizeof (buf),
+	(snprintf) (buf, sizeof (buf),
 				 "An IRC Client for UNIX.\n\n"
 				 "This binary was compiled on "__DATE__"\n"
 				 "Using GTK %d.%d.%d X %d\n"
@@ -119,7 +119,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	g_object_unref (head_style);
 	gtk_container_add (GTK_CONTAINER (vbox), label);
 
-	snprintf (buf, sizeof (buf),
+	(snprintf) (buf, sizeof (buf),
 				 "(C) 1998-2002 Peter Zelezny <zed@xchat.org>\n\n"
 				 "An IRC Client for UNIX.\n\n"
 				 "This binary was compiled on "__DATE__"\n"
