@@ -16,39 +16,41 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#define GTK_DISABLE_DEPRECATED
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 #include "fe-gtk.h"
+
+#include <gtk/gtkeditable.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkbutton.h>
+
 #include "../common/xchat.h"
 #include "../common/xchatc.h"
 #include "gtkutil.h"
-#include "wins.h"
 #include "ascii.h"
+#include "maingui.h"
 
 
 static void
 ascii_click (GtkWidget * wid, int c)
 {
-	int tmp_pos;
+	int tmp_pos, len;
 	unsigned char str = c;
-#ifdef WIN32
-	char *loc;
-	int ulen;
-#endif
+	char *locale;
 
-	if (menu_sess)
+	if (current_sess)
 	{
-		wid = menu_sess->gui->inputgad;
+		wid = current_sess->gui->input_box;
 		tmp_pos = gtk_editable_get_position (GTK_EDITABLE (wid));
-#ifdef WIN32
-		loc = g_locale_to_utf8 (&str, 1, NULL, &ulen, NULL);
-		gtk_editable_insert_text (GTK_EDITABLE (wid), loc, ulen, &tmp_pos);
-		g_free (loc);
-#else
-		gtk_editable_insert_text (GTK_EDITABLE (wid), &str, 1, &tmp_pos);
-#endif
-		gtk_entry_set_position (GTK_ENTRY (wid), tmp_pos);
+		locale = g_locale_to_utf8 (&str, 1, 0, &len, 0);
+		gtk_editable_insert_text (GTK_EDITABLE (wid), locale, len, &tmp_pos);
+		g_free (locale);
+		gtk_editable_set_position (GTK_EDITABLE (wid), tmp_pos);
 	}
 }
 
@@ -60,9 +62,10 @@ ascii_open (void)
 	unsigned char name[2], num[4];
 	GtkWidget *wid, *but, *hbox, *vbox, *win;
 	GtkStyle *style;
+	char *utf;
 
 	style = gtk_style_new ();
-	gdk_font_unref (style->font);
+	/*gdk_font_unref (style->font);
 	if (menu_sess && menu_sess->type == SESS_DIALOG)
 	{
       style->font = dialog_font_normal;
@@ -71,11 +74,10 @@ ascii_open (void)
 	{
 		style->font = font_normal;
 		gdk_font_ref (font_normal);
-	}
+	}*/
 
-	win = maingui_window ("asciichart", _("Ascii Chart"), TRUE, TRUE, NULL,
-									NULL, 0, 0, NULL);
-	vbox = wins_get_vbox (win);
+	win = mg_create_generic_tab ("asciichart", _("Ascii Chart"), TRUE, TRUE,
+										  NULL, NULL, 0, 0, &vbox);
 
 	name[1] = 0;
 
@@ -84,23 +86,25 @@ ascii_open (void)
 		hbox = gtk_hbox_new (0, 0);
 		sprintf (num, "%03d", i * 16);
 		wid = gtk_label_new (num);
-		gtk_widget_set_usize (wid, 36, 20);
+		gtk_widget_set_size_request (wid, 36, 20);
 		gtk_container_add (GTK_CONTAINER (hbox), wid);
 		gtk_widget_show (wid);
 		for (j = 0; j < 16; j++)
 		{
 			val = j + (i * 16);
 			name[0] = val;
-			but = gtk_button_new_with_label (name);
+			utf = g_locale_to_utf8 (name, 1, NULL, NULL, NULL);
+			but = gtk_button_new_with_label (utf);
+			g_free (utf);
 			gtk_widget_set_style (GTK_BIN (but)->child, style);
 			if (do_unref)
 			{
 				do_unref = FALSE;
-				gtk_style_unref (style);
+				g_object_unref (style);
 			}
-			gtk_signal_connect (GTK_OBJECT (but), "clicked",
-					    GTK_SIGNAL_FUNC (ascii_click), GINT_TO_POINTER (val));
-			gtk_widget_set_usize (but, 24, 20);
+			g_signal_connect (G_OBJECT (but), "clicked",
+									G_CALLBACK (ascii_click), GINT_TO_POINTER(val));
+			gtk_widget_set_size_request (but, 36, 20);
 			gtk_container_add (GTK_CONTAINER (hbox), but);
 			gtk_widget_show (but);
 		}
