@@ -56,11 +56,14 @@
 #ifndef WIN32
 
 static int
-reg_match (regex_t * regexptr, const char *str)
+reg_match (server *serv, const char *str)
 {
 	int m;
 
-	m = regexec (regexptr, str, 1, NULL, REG_NOTBOL);
+	if (!serv->gui->have_regex)
+		return 0;
+
+	m = regexec (&serv->gui->chanlist_match_regex, str, 1, NULL, REG_NOTBOL);
 
 	/* regex returns 0 if it's a match: */
 	return m == 0 ? 1 : 0;
@@ -69,9 +72,9 @@ reg_match (regex_t * regexptr, const char *str)
 #else
 
 static int
-reg_match (char ** regexptr, const char *str)
+reg_match (server *serv, const char *str)
 {
-	return match (*regexptr, str);
+	return match (serv->gui->chanlist_match_regex, str);
 }
 
 #endif
@@ -229,8 +232,8 @@ chanlist_place_row_in_gui (struct server *serv, gchar ** next_row)
 			 (!serv->gui->chanlist_match_wants_channel
 			  && !serv->gui->chanlist_match_wants_topic))
 		{
-			if (!reg_match (&serv->gui->chanlist_match_regex, next_row[0])
-				 && !reg_match (&serv->gui->chanlist_match_regex, next_row[2]))
+			if (!reg_match (serv, next_row[0])
+				 && !reg_match (serv, next_row[2]))
 			{
 				chanlist_update_caption (serv);
 				return;
@@ -239,7 +242,7 @@ chanlist_place_row_in_gui (struct server *serv, gchar ** next_row)
 
 		else if (serv->gui->chanlist_match_wants_channel)
 		{
-			if (!reg_match (&serv->gui->chanlist_match_regex, next_row[0]))
+			if (!reg_match (serv, next_row[0]))
 			{
 				chanlist_update_caption (serv);
 				return;
@@ -248,7 +251,7 @@ chanlist_place_row_in_gui (struct server *serv, gchar ** next_row)
 
 		else if (serv->gui->chanlist_match_wants_topic)
 		{
-			if (!reg_match (&serv->gui->chanlist_match_regex, next_row[2]))
+			if (!reg_match (serv, next_row[2]))
 			{
 				chanlist_update_caption (serv);
 				return;
@@ -385,22 +388,23 @@ chanlist_apply_pressed (GtkButton * button, struct server *serv)
 static void
 chanlist_wild (GtkWidget * wid, struct server *serv)
 {
+	char *pattern = GTK_ENTRY (wid)->text;
+
 	/* Store the pattern text in the wild_text var so next time the window is 
 	 * opened it is remembered. 
 	 */
-	safe_strcpy (serv->gui->chanlist_wild_text,
-					 gtk_entry_get_text (GTK_ENTRY (wid)),
+	safe_strcpy (serv->gui->chanlist_wild_text, pattern,
 					 sizeof (serv->gui->chanlist_wild_text));
 
 #ifdef WIN32
-	serv->gui->chanlist_match_regex =
-		strdup (gtk_entry_get_text (GTK_ENTRY (wid)));
+	serv->gui->chanlist_match_regex = strdup (pattern);
 #else
 	/* recompile the regular expression. */
-	regfree (&serv->gui->chanlist_match_regex);
-	regcomp (&serv->gui->chanlist_match_regex,
-				gtk_entry_get_text (GTK_ENTRY (wid)),
+	if (serv->gui->have_regex)
+		regfree (&serv->gui->chanlist_match_regex);
+	regcomp (&serv->gui->chanlist_match_regex, pattern,
 				REG_ICASE | REG_EXTENDED | REG_NOSUB);
+	serv->gui->have_regex = 1;
 #endif
 }
 
@@ -559,7 +563,11 @@ chanlist_destroy_widget (GtkObject * object, struct server *serv)
 {
 	chanlist_data_free (serv);
 #ifndef WIN32
-	regfree (&serv->gui->chanlist_match_regex);
+	if (serv->gui->have_regex)
+	{
+		regfree (&serv->gui->chanlist_match_regex);
+		serv->gui->have_regex = 0;
+	}
 #else
 	free (serv->gui->chanlist_match_regex);
 #endif
