@@ -48,13 +48,6 @@ struct dccwindow
 	GtkWidget *list;
 };
 
-struct dcc_send
-{
-	struct session *sess;
-	char nick[64];
-	GtkWidget *freq;
-};
-
 static struct dccwindow dccrwin;	/* recv */
 static struct dccwindow dccswin;	/* send */
 static struct dccwindow dcccwin;	/* chat */
@@ -100,7 +93,7 @@ fe_dcc_update_recv (struct DCC *dcc)
 	/* percentage done */
 	per = (float) ((dcc->pos * 100.00) / dcc->size);
 
-	snprintf (pos, sizeof (pos), "%d", dcc->pos);
+	snprintf (pos, sizeof (pos), "%u", dcc->pos);
 	snprintf (kbs, sizeof (kbs), "%.1f", ((float)dcc->cps) / 1024);
 	snprintf (perc, sizeof (perc), "%.0f%%", per);
 
@@ -147,9 +140,9 @@ fe_dcc_update_send (struct DCC *dcc)
 	/* percentage ack'ed */
 	per = (float) ((dcc->ack * 100.00) / dcc->size);
 
-	snprintf (pos, sizeof (pos), "%d", dcc->pos);
+	snprintf (pos, sizeof (pos), "%u", dcc->pos);
 	snprintf (kbs, sizeof (kbs), "%.1f", ((float)dcc->cps) / 1024);
-	snprintf (ack, sizeof (ack), "%d", dcc->ack);
+	snprintf (ack, sizeof (ack), "%u", dcc->ack);
 	snprintf (perc, sizeof (perc), "%.0f%%", per);
 	if (dcc->cps != 0)
 	{
@@ -220,11 +213,11 @@ fe_dcc_update_recv_win (void)
 			else
 				nnew[8] = "";
 #endif
-			sprintf (size, "%d", dcc->size);
+			sprintf (size, "%u", dcc->size);
 			if (dcc->dccstat == STAT_QUEUED)
-				sprintf (pos, "%d", dcc->resumable);
+				sprintf (pos, "%u", dcc->resumable);
 			else
-				sprintf (pos, "%d", dcc->pos);
+				sprintf (pos, "%u", dcc->pos);
 			snprintf (kbs, sizeof (kbs), "%.1f", ((float)dcc->cps) / 1024);
 			/* percentage recv'ed */
 			per = (float) ((dcc->pos * 100.00) / dcc->size);
@@ -256,7 +249,7 @@ dcc_info (struct DCC *dcc)
 	char tbuf[256];
 	snprintf (tbuf, 255, _("      File: %s\n"
 				 "   To/From: %s\n"
-				 "      Size: %d\n"
+				 "      Size: %u\n"
 				 "      Port: %d\n"
 				 " IP Number: %s\n"
 				 "Start Time: %s"),
@@ -485,11 +478,11 @@ fe_dcc_update_send_win (void)
 			nnew[8] = dcc->nick;
 			/* percentage ack'ed */
 			per = (float) ((dcc->ack * 100.00) / dcc->size);
-			snprintf (size, sizeof (size), "%d", dcc->size);
-			snprintf (pos, sizeof (pos), "%d", dcc->pos);
+			snprintf (size, sizeof (size), "%u", dcc->size);
+			snprintf (pos, sizeof (pos), "%u", dcc->pos);
 			snprintf (kbs, sizeof (kbs), "%.1f", ((float)dcc->cps) / 1024);
 			snprintf (perc, sizeof (perc), "%.0f%%", per);
-			snprintf (ack, sizeof (ack), "%d", dcc->ack);
+			snprintf (ack, sizeof (ack), "%u", dcc->ack);
 			if (dcc->cps != 0)
 			{
 				to_go = (dcc->size - dcc->ack) / dcc->cps;
@@ -673,8 +666,8 @@ fe_dcc_update_chat_win (void)
 		{
 			nnew[0] = _(dccstat[(int) dcc->dccstat].name);
 			nnew[1] = dcc->nick;
-			sprintf (pos, "%d", dcc->pos);
-			sprintf (siz, "%d", dcc->size);
+			sprintf (pos, "%u", dcc->pos);
+			sprintf (siz, "%u", dcc->size);
 			nnew[4] = ctime (&dcc->starttime);
 			nnew[4][strlen (nnew[4]) - 1] = 0;	/* remove the \n */
 			row = gtk_clist_append (GTK_CLIST (dcccwin.list), nnew);
