@@ -16,6 +16,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#define GTK_DISABLE_DEPRECATED
+
 #include <stdio.h>
 #include <string.h>
 #include "../../config.h"
@@ -73,16 +75,16 @@ extern void serverlist_autoconnect (struct session *sess, int);
 
 #ifdef USE_XLIB
 
-static GtkWidget *proxy_invisible;
-
 static void
 redraw_trans_xtexts (void)
 {
 	GSList *list = sess_list;
-	struct session *sess;
+	session *sess;
+	int done_main = FALSE;
+
 	while (list)
 	{
-		sess = (struct session *) list->data;
+		sess = list->data;
 #ifdef USE_ZVT
 		if (sess->type == SESS_SHELL)
 		{
@@ -90,25 +92,32 @@ redraw_trans_xtexts (void)
 			gtk_widget_queue_draw (sess->gui->xtext);
 		} else
 #endif
+		{
 			if (GTK_XTEXT (sess->gui->xtext)->transparent)
-				gtk_xtext_refresh (GTK_XTEXT (sess->gui->xtext), 1);
+			{
+				if (!sess->gui->is_tab || !done_main)
+					gtk_xtext_refresh (GTK_XTEXT (sess->gui->xtext), 1);
+				if (sess->gui->is_tab)
+					done_main = TRUE;
+			}
+		}
 		list = list->next;
 	}
 }
 
-static gboolean
-handle_property_notify (GtkWidget *widget, GdkEventProperty *event,
-								gpointer user_data)
+static GdkFilterReturn
+root_event_cb (GdkXEvent *xev, GdkEventProperty *event, gpointer data)
 {
-	static GdkAtom prop = GDK_NONE;
+	Atom at = None;
+	XEvent *xevent = (XEvent *)xev;
 
-	if (prop == GDK_NONE)
-		prop = gdk_atom_intern ("_XROOTPMAP_ID", TRUE);
+	if (at == None)
+		at = XInternAtom (GDK_DISPLAY (), "_XROOTPMAP_ID", True);
 
-	if (event->atom == prop)
+	if (xevent->type == PropertyNotify && at == xevent->xproperty.atom)
 		redraw_trans_xtexts ();
 
-	return FALSE;
+	return GDK_FILTER_CONTINUE;
 }
 
 #endif
@@ -119,7 +128,7 @@ fe_args (int argc, char *argv[])
 	int offset = 0;
 
 #ifdef ENABLE_NLS
-	bindtextdomain (PACKAGE, PREFIX"/share/locale");
+	bindtextdomain (PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
 #endif
@@ -191,17 +200,10 @@ fe_args (int argc, char *argv[])
 #endif
 
 #ifdef USE_XLIB
-	proxy_invisible = gtk_invisible_new ();
-	gtk_widget_show (proxy_invisible);
-
-	/* Make the root window send events to the invisible proxy widget */
-	gdk_window_set_user_data (GDK_ROOT_PARENT (), proxy_invisible);
-
-	/* Select for PropertyNotify events from the root window */
-	XSelectInput (GDK_DISPLAY (), GDK_ROOT_WINDOW (), PropertyChangeMask);
-
-	g_signal_connect (G_OBJECT (proxy_invisible), "property-notify-event",
-							G_CALLBACK (handle_property_notify), NULL);
+/*	XSelectInput (GDK_DISPLAY (), GDK_ROOT_WINDOW (), PropertyChangeMask);*/
+	gdk_window_set_events (gdk_get_default_root_window (), GDK_PROPERTY_CHANGE_MASK);
+	gdk_window_add_filter (gdk_get_default_root_window (),
+								  (GdkFilterFunc)root_event_cb, NULL);
 #endif
 
 	return 1;
@@ -256,9 +258,6 @@ fe_cleanup (void)
 {
 	palette_save ();
 
-	if (prefs.autosave_url)
-		url_autosave ();
-
 #ifdef USE_PANEL
 	panel_cleanup ();
 #endif
@@ -285,33 +284,7 @@ fe_timeout_remove (int tag)
 void
 fe_new_window (session *sess)
 {
-	static const char *locale = NULL;
-
 	mg_changui_new (sess, NULL);
-
-	if (locale == NULL)
-	{
-		fe_print_text (sess,
-			"*** THIS IS A DEVELOPMENT VERSION! *** "__DATE__" "VERSION" ***\n");
-		fe_print_text (sess,
-			"Your current locale is:\n");
-
-		g_get_charset (&locale);
-		fe_print_text (sess, (char *)locale);
-
-		if (strcmp (locale, "ANSI_X3.4-1968") == 0)
-			fe_print_text (sess, "\00304\002This locale restricts you to ASCII only!\002\017\n");
-
-		fe_print_text (sess,
-			"Set environmental variable LC_ALL to change \00312(\017e.g. \002export LC_ALL=en_US\002\00312)\017\n");
-#ifdef USE_PANGO
-		fe_print_text (sess, "Using Pango for text rendering. This will be slow!\n");
-#endif
-#ifdef USE_XFT
-		fe_print_text (sess, "Using Xft for text rendering (good!).\n");
-
-#endif
-	}
 }
 
 void
@@ -513,25 +486,37 @@ updatedate_bar (struct session *sess)
 		}
 		pos = 0.05;
 	}
-	gtk_progress_bar_update ((GtkProgressBar *) sess->gui->bar, pos);
+	gtk_progress_bar_set_fraction ((GtkProgressBar *) sess->gui->bar, pos);
 	return 1;
 }
 
 void
-fe_progressbar_start (struct session *sess)
+fe_progressbar_start (session *sess)
 {
-	if (sess->gui->nick_box)
+	if (!sess->gui->is_tab || current_tab == sess)
 	{
 		sess->gui->bar = gtk_progress_bar_new ();
 		gtk_box_pack_start (GTK_BOX (sess->gui->nick_box), sess->gui->bar, 0, 0,
 								  0);
 		gtk_widget_show (sess->gui->bar);
 		sess->server->bartag = fe_timeout_add (50, updatedate_bar, sess);
+	} else
+	{
+		sess->res->c_graph = TRUE;
 	}
 }
 
 void
-fe_progressbar_end (struct server *serv)
+fe_progressbar_destroy (session *sess)
+{
+	fe_timeout_remove (sess->server->bartag);
+	if (GTK_IS_WIDGET (sess->gui->bar))
+		gtk_widget_destroy (sess->gui->bar);
+	sess->gui->bar = 0;
+}
+
+void
+fe_progressbar_end (server *serv)
 {
 	GSList *list = sess_list;
 	session *sess;
@@ -539,13 +524,12 @@ fe_progressbar_end (struct server *serv)
 	while (list)				  /* check all windows that use this server and  *
 									   * remove the connecting graph, if it has one. */
 	{
-		sess = (struct session *) list->data;
-		if (sess->server == serv && sess->gui->bar)
+		sess = list->data;
+		if (sess->server == serv)
 		{
-			fe_timeout_remove (sess->server->bartag);
-			if (GTK_IS_WIDGET (sess->gui->bar))
-				gtk_widget_destroy (sess->gui->bar);
-			sess->gui->bar = 0;
+			if (sess->gui->bar)
+				fe_progressbar_destroy (sess);
+			sess->res->c_graph = FALSE;
 		}
 		list = list->next;
 	}
@@ -653,7 +637,7 @@ fe_set_lag (server *serv, int lag)
 			{
 				if (sess->gui->lagometer)
 				{
-					gtk_progress_bar_update ((GtkProgressBar *) sess->gui->lagometer, per);
+					gtk_progress_bar_set_fraction ((GtkProgressBar *) sess->gui->lagometer, per);
 				}
 				if (sess->gui->laginfo)
 				{
@@ -691,7 +675,7 @@ fe_set_throttle (server *serv)
 			{
 				if (sess->gui->throttlemeter)
 				{
-					gtk_progress_bar_update ((GtkProgressBar *) sess->gui->throttlemeter, per);
+					gtk_progress_bar_set_fraction ((GtkProgressBar *) sess->gui->throttlemeter, per);
 				}
 				if (sess->gui->throttleinfo)
 				{
