@@ -59,6 +59,7 @@ struct server_gui
 
 #ifndef WIN32
 	regex_t chanlist_match_regex;	/* compiled regular expression here */
+	unsigned int have_regex:1;
 #else
 	char *chanlist_match_regex;
 #endif
@@ -92,6 +93,7 @@ typedef struct restore_gui
 	gfloat queue_value; /* outbound queue meter */
 	short flag_wid_state[NUM_FLAG_WIDS];
 	char prefix;	/* my prefix char. e.g. @ for ops */
+	unsigned int c_graph:1;	/* connecting graph, is there one? */
 } restore_gui;
 
 typedef struct session_gui
