@@ -227,12 +227,14 @@ key_get_key_name (int keyval)
  */
 
 gboolean
-key_handle_key_press (GtkWidget *wid, GdkEventKey *evt, gpointer user_data)
+key_handle_key_press (GtkWidget *wid, GdkEventKey *evt, session *sess)
 {
 	struct key_binding *kb, *last = NULL;
 	int keyval = evt->keyval;
 	int mod, n;
-	session *sess = current_sess;
+
+	if (!sess)
+		sess = current_sess;
 
 	mod = evt->state & (STATE_CTRL | STATE_ALT | STATE_SHIFT);
 
@@ -1808,7 +1810,7 @@ tab_nick_comp (session *sess, GtkWidget *t, int shift)
 				if (match_char == 0xff)
 				{
 					match_char = current_nick[match_pos];
-				} else if (tolower (current_nick[match_pos]) != tolower (match_char))
+				} else if (rfc_tolower (current_nick[match_pos]) != rfc_tolower (match_char))
 				{
 					match_text = malloc (match_pos + 1);
 					memcpy (match_text, current_nick, match_pos);
