@@ -23,11 +23,21 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include "fe-gtk.h"
+
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkclist.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkhbbox.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkhseparator.h>
+
 #include "../common/xchat.h"
 #include "../common/ignore.h"
 #include "../common/cfgfiles.h"
 #include "gtkutil.h"
-#include "wins.h"
+#include "maingui.h"
 
 
 static GtkWidget *ignorewin = 0;
@@ -75,22 +85,22 @@ ignore_save_clist_tomem (void)
 		ignore->mask = strdup (tmp);
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 1, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->ctcp = 1;
+			ignore->type |= IG_CTCP;
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 2, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->priv = 1;
+			ignore->type |= IG_PRIV;
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 3, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->chan = 1;
+			ignore->type |= IG_CHAN;
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 4, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->noti = 1;
+			ignore->type |= IG_NOTI;
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 5, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->invi = 1;
+			ignore->type |= IG_INVI;
 		gtk_clist_get_text (GTK_CLIST (ignorelist), i, 6, &tmp);
 		if (!strcmp (tmp, _("Yes")))
-			ignore->unignore = 1;
+			ignore->type |= IG_UNIG;
 		ignore_list = g_slist_append (ignore_list, ignore);
 		i++;
 	}
@@ -102,27 +112,27 @@ ignore_add_clist_entry (struct ignore *ignore)
 	char *nnew[7];
 
 	nnew[0] = ignore->mask;
-	if (ignore->ctcp)
+	if (ignore->type & IG_CTCP)
 		nnew[1] = _("Yes");
 	else
 		nnew[1] = _("No");
-	if (ignore->priv)
+	if (ignore->type & IG_PRIV)
 		nnew[2] = _("Yes");
 	else
 		nnew[2] = _("No");
-	if (ignore->chan)
+	if (ignore->type & IG_CHAN)
 		nnew[3] = _("Yes");
 	else
 		nnew[3] = _("No");
-	if (ignore->noti)
+	if (ignore->type & IG_NOTI)
 		nnew[4] = _("Yes");
 	else
 		nnew[4] = _("No");
-	if (ignore->invi)
+	if (ignore->type & IG_INVI)
 		nnew[5] = _("Yes");
 	else
 		nnew[5] = _("No");
-	if (ignore->unignore)
+	if (ignore->type & IG_UNIG)
 		nnew[6] = _("Yes");
 	else
 		nnew[6] = _("No");
@@ -201,7 +211,9 @@ ignore_row_selected (GtkWidget * clist, int row, int column,
 	if (row != -1)
 	{
 		gtk_clist_get_text (GTK_CLIST (ignorelist), row, 0, &mask);
+		mask = strdup (mask);
 		gtk_entry_set_text (GTK_ENTRY (entry_mask), mask);
+		free (mask);
 		ignore_check_state_toggled (entry_ctcp, row, 1);
 		ignore_check_state_toggled (entry_private, row, 2);
 		ignore_check_state_toggled (entry_channel, row, 3);
@@ -216,7 +228,7 @@ static void
 ignore_handle_mask (GtkWidget * igad)
 {
 	int row;
-	char *mask;
+	const char *mask;
 
 	row = gtkutil_clist_selection (ignorelist);
 	if (row != -1)
@@ -317,7 +329,7 @@ ignore_stats_entry (GtkWidget * box, char *label, int value)
 	gtkutil_label_new (label, box);
 	wid = gtkutil_entry_new (16, box, 0, 0);
 	gtk_widget_set_usize (wid, 30, 0);
-	gtk_entry_set_editable (GTK_ENTRY (wid), FALSE);
+	gtk_editable_set_editable (GTK_EDITABLE (wid), FALSE);
 	gtk_entry_set_text (GTK_ENTRY (wid), buf);
 
 	return wid;
@@ -326,28 +338,21 @@ ignore_stats_entry (GtkWidget * box, char *label, int value)
 void
 ignore_gui_open ()
 {
-	gchar *titles[7];
+	gchar *titles[] =
+		{ _("Mask"), _("CTCP"), _("Private"), _("Chan"), _("Notice"), _("Invite"), _("Unignore") };
 	GtkWidget *vbox, *box, *wid, *stat_box, *frame;
 	GSList *temp = ignore_list;
 
-	titles[0] = _("Mask");
-	titles[1] = _("CTCP");
-	titles[2] = _("Private");
-	titles[3] = _("Chan");
-	titles[4] = _("Notice");
-	titles[5] = _("Invite");
-	titles[6] = _("Unignore");
-
 	if (ignorewin)
 	{
-		wins_bring_tofront (ignorewin);
+		mg_bring_tofront (ignorewin);
 		return;
 	}
 
-	ignorewin = maingui_window ("ignorelist", _("X-Chat: Ignore list"),
+	ignorewin =
+			  mg_create_generic_tab ("ignorelist", _("X-Chat: Ignore list"),
 											FALSE, TRUE, close_ignore_gui_callback,
-											NULL, 0, 0, &ignorewin);
-	vbox = wins_get_vbox (ignorewin);
+											NULL, 0, 0, &vbox);
 
 	ignorelist = gtkutil_clist_new (7, titles, vbox, GTK_POLICY_ALWAYS,
 											  ignore_row_selected, 0,
@@ -430,21 +435,20 @@ ignore_gui_open ()
 
 	gtk_container_add (GTK_CONTAINER (vbox), frame);
 
-	box = gtk_hbox_new (0, 2);
-	gtk_container_set_border_width (GTK_CONTAINER (box), 2);
-	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 2);
+	box = gtk_hbutton_box_new ();
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (box), GTK_BUTTONBOX_SPREAD);
+	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 2);
 	gtk_widget_show (box);
 
-	gtkutil_button (ignorewin, GNOME_STOCK_BUTTON_OK, _("OK"),
-						 close_ignore_list, 0, box);
-	gtkutil_button (ignorewin, GNOME_STOCK_PIXMAP_NEW, _("New"),
-						 ignore_new_entry_clicked, 0, box);
-	gtkutil_button (ignorewin, GNOME_STOCK_PIXMAP_CLOSE, _("Delete"),
-						 ignore_delete_entry_clicked, 0, box);
-	gtkutil_button (ignorewin, GNOME_STOCK_PIXMAP_SPELLCHECK, _("Sort"),
-						 ignore_sort_clicked, 0, box);
-	gtkutil_button (ignorewin, GNOME_STOCK_BUTTON_CANCEL, _("Cancel"),
-						 gtkutil_destroy, ignorewin, box);
+	gtkutil_button (box, GTK_STOCK_OK, 0, close_ignore_list, 0, _("OK"), 0, 0);
+	gtkutil_button (box, GTK_STOCK_NEW, 0, ignore_new_entry_clicked, 0,
+						 _("New"), 0, 0);
+	gtkutil_button (box, GTK_STOCK_CLOSE, 0, ignore_delete_entry_clicked,
+						 0, ("Delete"), 0, 0);
+	gtkutil_button (box, GTK_STOCK_SPELL_CHECK, 0, ignore_sort_clicked,
+						 0, _("Sort"), 0, 0);
+	gtkutil_button (box, GTK_STOCK_CANCEL, 0, gtkutil_destroy, ignorewin,
+						 _("Cancel"), 0, 0);
 
 	while (temp)
 	{
