@@ -73,7 +73,7 @@ GtkStyle *blue_style;
 GtkStyle *input_style;
 
 
-static void mg_create_entry (session_gui *gui, GtkWidget *box);
+static void mg_create_entry (session *sess, GtkWidget *box);
 
 
 static void
@@ -272,6 +272,12 @@ mg_unpopulate (session *sess)
 	if (gui->throttlemeter)
 		res->queue_value = gtk_progress_bar_get_fraction (
 													GTK_PROGRESS_BAR (gui->throttlemeter));
+
+	if (gui->bar)
+	{
+		res->c_graph = TRUE;	/* still have a graph, just not visible now */
+		fe_progressbar_destroy (sess);
+	}
 }
 
 static void
@@ -326,7 +332,7 @@ mg_populate (session *sess)
 	restore_gui *res = sess->res;
 	int i;
 
-/*printf("enter mg_populate (sess=%p)\n", sess);*/
+printf("enter mg_populate (sess=%p)\n", sess);
 
 	switch (sess->type)
 	{
@@ -392,6 +398,13 @@ mg_populate (session *sess)
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (gui->throttlemeter),
 												 res->queue_value);
 
+	/* did this tab have a connecting graph? restore it.. */
+	if (res->c_graph)
+	{
+		res->c_graph = FALSE;
+		fe_progressbar_start (sess);
+	}
+
 	if (gui->is_tab)
 		GTK_CHECK_MENU_ITEM (gui->away_item)->active = sess->server->is_away;
 
@@ -469,7 +482,7 @@ mg_ircdestroy (GtkWidget *tab, session *sess)
 {
 	GSList *list;
 
-/*	printf("enter mg_ircdestroy. sess %p was destroyed\n", sess);*/
+	printf("enter mg_ircdestroy. sess %p was destroyed\n", sess);
 
 	/* kill the text buffer */
 	gtk_xtext_buffer_free (sess->res->buffer);
@@ -780,8 +793,18 @@ mg_x_click_cb (GtkWidget *button, gpointer userdata)
 void
 mg_changui_destroy (session *sess)
 {
-	free (sess->gui);
-	sess->gui = NULL;
+printf("changui_destroy sess=%p gui=%p (tab=%d)\n", sess, sess->gui, sess->gui->is_tab);
+	if (sess->gui->is_tab)
+	{
+		/* avoid calling the "destroy" callback */
+		g_signal_handlers_disconnect_by_func (G_OBJECT (sess->gui->tab),
+														  mg_tabdestroy_cb, sess);
+		tab_remove (sess->gui->tab);
+	} else
+	{
+		free (sess->gui);
+		sess->gui = NULL;
+	}
 }
 
 static void
@@ -789,6 +812,8 @@ mg_link_irctab (session *sess)
 {
 	int old;
 
+printf("*********  DELINK *********** sess=%p buffer=%p\n", sess, sess->res->buffer);
+
 	if (sess->gui->is_tab)
 	{
 		mg_changui_destroy (sess);
@@ -799,6 +824,9 @@ mg_link_irctab (session *sess)
 		mg_changui_new (sess, sess->res);
 
 		prefs.tabchannels = old;
+
+		mg_populate (sess);
+
 		return;
 	}
 
@@ -844,13 +872,19 @@ check_is_number (char *t)
 static void
 mg_change_flag (GtkWidget * wid, session *sess, char flag)
 {
-	if (sess->server->connected && sess->channel[0])
+	server *serv = sess->server;
+	char mode[3];
+
+	mode[1] = flag;
+	mode[2] = '\0';
+	if (serv->connected && sess->channel[0])
 	{
 		if (GTK_TOGGLE_BUTTON (wid)->active)
-			tcp_sendf (sess->server, "MODE %s +%c\r\n", sess->channel, flag);
+			mode[0] = '+';
 		else
-			tcp_sendf (sess->server, "MODE %s -%c\r\n", sess->channel, flag);
-		tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+			mode[0] = '-';
+		serv->p_chan_mode (serv, sess->channel, mode);
+		serv->p_join_info (serv, sess->channel);
 		sess->ignore_mode = TRUE;
 		sess->ignore_date = TRUE;
 	}
@@ -859,11 +893,13 @@ mg_change_flag (GtkWidget * wid, session *sess, char flag)
 static void
 flagl_hit (GtkWidget * wid, struct session *sess)
 {
+	char modes[512];
 	const char *limit_str;
+	server *serv = sess->server;
 
 	if (GTK_TOGGLE_BUTTON (wid)->active)
 	{
-		if (sess->server->connected && sess->channel[0])
+		if (serv->connected && sess->channel[0])
 		{
 			limit_str = gtk_entry_get_text (GTK_ENTRY (sess->gui->limit_entry));
 			if (check_is_number ((char *)limit_str) == FALSE)
@@ -873,9 +909,9 @@ flagl_hit (GtkWidget * wid, struct session *sess)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), FALSE);
 				return;
 			}
-			tcp_sendf (sess->server, "MODE %s +l %d\r\n", sess->channel,
-						  atoi (limit_str));
-			tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+			snprintf (modes, sizeof (modes), "+l %d", atoi (limit_str));
+			serv->p_chan_mode (serv, sess->channel, modes);
+			serv->p_join_info (serv, sess->channel);
 		}
 	} else
 		mg_change_flag (wid, sess, 'l');
@@ -884,18 +920,18 @@ flagl_hit (GtkWidget * wid, struct session *sess)
 static void
 flagk_hit (GtkWidget * wid, struct session *sess)
 {
-	if (sess->server->connected && sess->channel[0])
+	char modes[512];
+	server *serv = sess->server;
+
+	if (serv->connected && sess->channel[0])
 	{
+		snprintf (modes, sizeof (modes), "-k %s", 
+			  gtk_entry_get_text (GTK_ENTRY (sess->gui->key_entry)));
+
 		if (GTK_TOGGLE_BUTTON (wid)->active)
-		{
-			tcp_sendf (sess->server, "MODE %s +k %s\r\n", sess->channel,
-						 gtk_entry_get_text (GTK_ENTRY (sess->gui->key_entry)));
-		} else
-		{
-			tcp_sendf (sess->server, "MODE %s -k %s\r\n", sess->channel,
-						 gtk_entry_get_text (GTK_ENTRY (sess->gui->key_entry)));
-		}
-		tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+			modes[0] = '+';
+
+		serv->p_chan_mode (serv, sess->channel, modes);
 	}
 }
 
@@ -949,34 +985,39 @@ mg_create_flagbutton (char *tip, GtkWidget *box, char *face)
 static void
 mg_key_entry_cb (GtkWidget * igad, gpointer userdata)
 {
+	char modes[512];
 	session *sess = current_sess;
+	server *serv = sess->server;
 
-	if (sess->server->connected && sess->channel[0])
+	if (serv->connected && sess->channel[0])
 	{
-		tcp_sendf (sess->server, "MODE %s +k %s\r\n", sess->channel,
-					  gtk_entry_get_text (GTK_ENTRY (igad)));
-		tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+		snprintf (modes, sizeof (modes), "+k %s",
+				gtk_entry_get_text (GTK_ENTRY (igad)));
+		serv->p_chan_mode (serv, sess->channel, modes);
+		serv->p_join_info (serv, sess->channel);
 	}
 }
 
 static void
 mg_limit_entry_cb (GtkWidget * igad, gpointer userdata)
 {
+	char modes[512];
 	session *sess = current_sess;
+	server *serv = sess->server;
 
-	if (sess->server->connected && sess->channel[0])
+	if (serv->connected && sess->channel[0])
 	{
 		if (check_is_number ((char *)gtk_entry_get_text (GTK_ENTRY (igad))) == FALSE)
 		{
 			gtk_entry_set_text (GTK_ENTRY (igad), "");
 			gtkutil_simpledialog (_("User limit must be a number!\n"));
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sess->gui->flag_l),
-												  FALSE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sess->gui->flag_l), FALSE);
 			return;
 		}
-		tcp_sendf (sess->server, "MODE %s +l %d\r\n", sess->channel,
-					  atoi (gtk_entry_get_text (GTK_ENTRY (igad))));
-		tcp_sendf (sess->server, "MODE %s\r\n", sess->channel);
+		snprintf (modes, sizeof(modes), "+l %d", 
+				atoi (gtk_entry_get_text (GTK_ENTRY (igad))));
+		serv->p_chan_mode (serv, sess->channel, modes);
+		serv->p_join_info (serv, sess->channel);
 	}
 }
 
@@ -1232,7 +1273,7 @@ mg_update_xtext (GtkWidget *wid)
 	gtk_xtext_set_tint (xtext, prefs.tint_red, prefs.tint_green, prefs.tint_blue);
 	gtk_xtext_set_background (xtext, channelwin_pix, prefs.transparent, prefs.tint);
 	gtk_xtext_set_wordwrap (xtext, prefs.wordwrap);
-	gtk_xtext_set_show_separator (xtext, prefs.show_separator);
+	gtk_xtext_set_show_separator (xtext, prefs.indent_nicks ? prefs.show_separator : 0);
 	if (!gtk_xtext_set_font (xtext, prefs.font_normal))
 	{
 		fe_message ("Failed to open any font. I'm out of here!", TRUE);
@@ -1258,6 +1299,7 @@ mg_create_textarea (session_gui *gui, GtkWidget *box)
 	gtk_container_add (GTK_CONTAINER (hbox), frame);
 
 	gui->xtext = gtk_xtext_new (colors, TRUE);
+printf("new xtext (%p) for gui %p\n", gui->xtext, gui);
 	xtext = GTK_XTEXT (gui->xtext);
 	gtk_xtext_set_max_indent (xtext, prefs.max_auto_indent);
 	gtk_xtext_set_thin_separator (xtext, prefs.thin_separator);
@@ -1360,7 +1402,7 @@ mg_create_userlist (session_gui *gui, GtkWidget *box)
 }
 
 static void
-mg_create_center (session_gui *gui, GtkWidget *box)
+mg_create_center (session *sess, session_gui *gui, GtkWidget *box)
 {
 	GtkWidget *vbox, *hbox, *tbox, *paned;
 
@@ -1381,7 +1423,7 @@ mg_create_center (session_gui *gui, GtkWidget *box)
 
 		mg_create_textarea (gui, vbox);
 		mg_create_userlist (gui, tbox);
-		mg_create_entry (gui, vbox);
+		mg_create_entry (sess, vbox);
 
 	} else
 	{
@@ -1393,7 +1435,7 @@ mg_create_center (session_gui *gui, GtkWidget *box)
 
 		mg_create_textarea (gui, vbox);
 		mg_create_userlist (gui, hbox);
-		mg_create_entry (gui, vbox);
+		mg_create_entry (sess, vbox);
 	}
 }
 
@@ -1437,7 +1479,7 @@ mg_upbutton_cb (GtkButton *but, gpointer userdata)
 
 	menu = gtk_menu_new ();
 
-	item = gtk_menu_item_new_with_label (_("Channnel settings"));
+	item = gtk_menu_item_new_with_label (_("Channel settings"));
 	gtk_widget_set_sensitive (item, FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	gtk_widget_show (item);
@@ -1521,9 +1563,10 @@ mg_set_tabs_pos (session_gui *gui, int pos)
 }
 
 static void
-mg_create_entry (session_gui *gui, GtkWidget *box)
+mg_create_entry (session *sess, GtkWidget *box)
 {
 	GtkWidget *hbox, *but, *entry;
+	session_gui *gui = sess->gui;
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (box), hbox, 0, 0, 0);
@@ -1538,10 +1581,13 @@ mg_create_entry (session_gui *gui, GtkWidget *box)
 	g_signal_connect (G_OBJECT (but), "clicked",
 							G_CALLBACK (mg_nickclick_cb), NULL);
 
+	if (gui->is_tab)
+		sess = NULL;	/* pass NULL to key_handle_key_press for tabs */
+
 	gui->input_box = entry = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY (gui->input_box), 2048);
 	g_signal_connect (G_OBJECT (gui->input_box), "key_press_event",
-							G_CALLBACK (key_handle_key_press), 0);
+							G_CALLBACK (key_handle_key_press), sess);
 	gtk_container_add (GTK_CONTAINER (hbox), entry);
 	gtk_widget_grab_focus (entry);
 
@@ -1577,13 +1623,20 @@ mg_switch_tab_cb (GtkWidget *tab, session *sess, gpointer family)
 static void
 mg_create_tabs (session_gui *gui, GtkWidget *box)
 {
-/*	GtkWidget *frame;
+/*	GtkWidget *sc;
+	GtkWidget *frame;
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	gtk_box_pack_start (GTK_BOX (box), frame, 0, 0, 0);*/
 
 	gui->tabs_box = tab_group_new (mg_switch_tab_cb);
+
+/*	sc = gtk_scrolled_window_new (0, 0);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sc),
+											  GTK_POLICY_AUTOMATIC, GTK_POLICY_NEVER);
+	gtk_scrolled_window_add_with_viewport (sc, gui->tabs_box);*/
+
 	gtk_box_pack_start (GTK_BOX (box), gui->tabs_box, 0, 0, 0);
 /*	gtk_container_add (GTK_CONTAINER (frame), gui->tabs_box);*/
 }
@@ -1591,6 +1644,7 @@ mg_create_tabs (session_gui *gui, GtkWidget *box)
 static gboolean
 mg_tabwin_focus_cb (GtkWindow * win, GdkEventFocus *event, gpointer userdata)
 {
+printf("focus tabwin\n");
 	current_sess = current_tab;
 	plugin_emit_dummy_print (current_sess, "Focus Window");
 	return FALSE;
@@ -1599,6 +1653,7 @@ mg_tabwin_focus_cb (GtkWindow * win, GdkEventFocus *event, gpointer userdata)
 static gboolean
 mg_topwin_focus_cb (GtkWindow * win, GdkEventFocus *event, session *sess)
 {
+printf("focus toplevel\n");
 	current_sess = sess;
 	if (!sess->server->server_session)
 		sess->server->server_session = sess;
@@ -1617,7 +1672,6 @@ mg_create_topwindow (session *sess)
 									  prefs.mainwindow_height, FALSE);
 	sess->gui->window = win;
 	gtk_container_set_border_width (GTK_CONTAINER (win), 2);
-
 	g_signal_connect (G_OBJECT (win), "focus_in_event",
 							G_CALLBACK (mg_topwin_focus_cb), sess);
 	g_signal_connect (G_OBJECT (win), "destroy",
@@ -1630,13 +1684,14 @@ mg_create_topwindow (session *sess)
 	gtk_container_add (GTK_CONTAINER (vbox), vvbox);
 
 	mg_create_topicbar (sess->gui, vvbox, sess->channel);
-	mg_create_center (sess->gui, vvbox);
+	mg_create_center (sess, sess->gui, vvbox);
 
 	if (sess->res->buffer == NULL)
 	{
 		sess->res->buffer = GTK_XTEXT (sess->gui->xtext)->orig_buffer;
 		sess->res->user_model = userlist_create_model ();
 	}
+
 	userlist_show (sess);
 
 	gtk_widget_show_all (win);
@@ -1652,14 +1707,15 @@ mg_create_menu (session_gui *gui, GtkWidget *box, int away_state)
 }
 
 static void
-mg_create_irctab (session_gui *gui, GtkWidget *book)
+mg_create_irctab (session *sess, GtkWidget *book)
 {
 	GtkWidget *vbox;
+	session_gui *gui = sess->gui;
 
 	vbox = gtk_vbox_new (FALSE, 0);
 
 	mg_create_topicbar (gui, vbox, NULL);
-	mg_create_center (gui, vbox);
+	mg_create_center (sess, gui, vbox);
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (book), vbox, NULL);
 }
@@ -1750,7 +1806,7 @@ mg_create_tabwindow (session *sess)
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (book), FALSE);
 	gtk_container_add (GTK_CONTAINER (vbox), book);
 
-	mg_create_irctab (sess->gui, book);
+	mg_create_irctab (sess, book);
 	mg_create_tabs (sess->gui, vbox);
 	mg_create_menu (sess->gui, vbox, sess->server->is_away);
 
@@ -1957,6 +2013,8 @@ mg_changui_new (session *sess, restore_gui *res)
 	int first_run = FALSE;
 	session_gui *gui;
 
+printf("changui_new sess=%p gui=%p\n", sess, sess->gui);
+
 	gui = malloc (sizeof (session_gui));
 	memset (gui, 0, sizeof (session_gui));
 
@@ -1977,6 +2035,7 @@ mg_changui_new (session *sess, restore_gui *res)
 		gui->is_tab = FALSE;
 		mg_create_topwindow (sess);
 		fe_set_title (sess);
+printf("changui_new finished. sess=%p gui=%p (xtext=%p)\n", sess, sess->gui, sess->gui->xtext);
 		return;
 	}
 
