@@ -635,7 +635,7 @@ menu_chanmenu (struct session *sess, GdkEventButton * event, char *chan)
 	GtkWidget *menu;
 	int is_joined = FALSE;
 
-	if (find_session_from_channel (chan, sess->server))
+	if (find_channel (sess->server, chan))
 		is_joined = TRUE;
 
 	if (str_copy)
@@ -661,17 +661,10 @@ menu_chanmenu (struct session *sess, GdkEventButton * event, char *chan)
 	menu_popup (menu, event);
 }
 
-static void
-menu_open_server_list2 (GtkWidget *wid, gpointer none)
-{
-	servlist_open (current_sess);
-}
-
-
 static void
 menu_open_server_list (GtkWidget *wid, gpointer none)
 {
-  	fe_open_serverlist (current_sess, FALSE, FALSE);
+	fe_serverlist_open (current_sess);
 }
 
 static void
@@ -997,30 +990,36 @@ menu_savebuffer (GtkWidget * wid, gpointer none)
 static void
 menu_wallops (GtkWidget * wid, gpointer none)
 {
+	char mode[3];
+	server *serv = current_sess->server;
 	prefs.wallops = !prefs.wallops;
-	if (current_sess->server->connected)
+	if (serv->connected)
 	{
+		mode[1] = 'w';
+		mode[2] = '\0';
 		if (prefs.wallops)
-			tcp_sendf (current_sess->server, "MODE %s +w\r\n",
-						  current_sess->server->nick);
+			mode[0] = '+';
 		else
-			tcp_sendf (current_sess->server, "MODE %s -w\r\n",
-						  current_sess->server->nick);
+			mode[0] = '-';
+		serv->p_nick_mode (serv, serv->nick, mode);
 	}
 }
 
 static void
 menu_servernotice (GtkWidget * wid, gpointer none)
 {
+	char mode[3];
+	server *serv = current_sess->server;
 	prefs.servernotice = !prefs.servernotice;
-	if (current_sess->server->connected)
+	if (serv->connected)
 	{
+		mode[1] = 's';
+		mode[2] = '\0';
 		if (prefs.servernotice)
-			tcp_sendf (current_sess->server, "MODE %s +s\r\n",
-						  current_sess->server->nick);
+			mode[0] = '+';
 		else
-			tcp_sendf (current_sess->server, "MODE %s -s\r\n",
-						  current_sess->server->nick);
+			mode[0] = '-';
+		serv->p_nick_mode (serv, serv->nick, mode);
 	}
 }
 
@@ -1033,15 +1032,18 @@ menu_away (GtkWidget * wid, gpointer none)
 static void
 menu_invisible (GtkWidget * wid, gpointer none)
 {
+	char mode[3];
+	server *serv = current_sess->server;
 	prefs.invisible = !prefs.invisible;
 	if (current_sess->server->connected)
 	{
+		mode[1] = 'i';
+		mode[2] = '\0';
 		if (prefs.invisible)
-			tcp_sendf (current_sess->server, "MODE %s +i\r\n",
-						  current_sess->server->nick);
+			mode[0] = '+';
 		else
-			tcp_sendf (current_sess->server, "MODE %s -i\r\n",
-						  current_sess->server->nick);
+			mode[0] = '-';
+		serv->p_nick_mode (serv, serv->nick, mode);
 	}
 }
 
@@ -1286,14 +1288,13 @@ menu_dcc_chat_win (GtkWidget *wid, gpointer none)
 static struct mymenu mymenu[] = {
 	{N_("X-Chat"), 0, 0, M_NEWMENU, 0, 1},
 	{N_("Server List..."), menu_open_server_list, (char *)&pix_book, M_MENUPIX, 0, 1},
-	{N_("Server List 2..."), menu_open_server_list2, (char *)&pix_book, M_MENUPIX, 0, 1},
 	{0, 0, 0, M_SEP, 0, 0},
 	{N_("New Server Tab..."), menu_newserver_tab, 0, M_MENU, 0, 1},
 	
 	{N_("New Server Window..."), menu_newserver_window, 0, M_MENU, 0, 1},
 	{N_("New Channel Tab..."), menu_newchannel_tab, 0, M_MENU, 0, 1},
 	{N_("New Channel Window..."), menu_newchannel_window, 0, M_MENU, 0, 1},
-	{0, 0, 0, M_SEP, 0, 0},	/* 8 */
+	{0, 0, 0, M_SEP, 0, 0},	/* 7 */
 #ifdef USE_ZVT
 	{N_("New Shell Tab..."), menu_newshell_tab, 0, M_MENU, 0, 1},
 	{0, 0, 0, M_SEP, 0, 0},
@@ -1303,7 +1304,7 @@ static struct mymenu mymenu[] = {
 #endif
 	{N_("Close"), menu_close, GTK_STOCK_CLOSE, M_MENUSTOCK, 0, 1},
 	{0, 0, 0, M_SEP, 0, 0},
-	{N_("Quit"), mg_safe_quit, GTK_STOCK_QUIT, M_MENUSTOCK, 0, 1},	/* 13 */
+	{N_("Quit"), mg_safe_quit, GTK_STOCK_QUIT, M_MENUSTOCK, 0, 1},	/* 12 */
 
 	{N_("Windows"), 0, 0, M_NEWMENU, 0, 1},
 	{N_("Channel List Window..."), menu_chanlist, 0, M_MENU, 0, 1},
@@ -1319,7 +1320,7 @@ static struct mymenu mymenu[] = {
 	{0, 0, 0, M_SEP, 0, 0},
 	{N_("F_lush Buffer"), menu_flushbuffer, GTK_STOCK_CLEAR, M_MENUSTOCK, 0, 1},
 	{N_("Search Buffer..."), menu_search, GTK_STOCK_FIND, M_MENUSTOCK, 0, 1},
-	{N_("Save Buffer..."), menu_savebuffer, GTK_STOCK_SAVE, M_MENUSTOCK, 0, 1},	/* 28 */
+	{N_("Save Buffer..."), menu_savebuffer, GTK_STOCK_SAVE, M_MENUSTOCK, 0, 1},	/* 27 */
 
 	{N_("User Modes"), 0, 0, M_NEWMENU, 0, 1},
 	{N_("Invisible"), menu_invisible, 0, M_MENUTOG, 1, 1},
@@ -1327,11 +1328,11 @@ static struct mymenu mymenu[] = {
 	{N_("Receive Server Notices"), menu_servernotice, 0, M_MENUTOG, 1, 1},
 	{0, 0, 0, M_SEP, 0, 0},
 	{N_("Marked Away"), menu_away, 0, M_MENUTOG, 0, 1},
-	{0, 0, 0, M_SEP, 0, 0},														/* 35 */
+	{0, 0, 0, M_SEP, 0, 0},														/* 34 */
 	{N_("Auto ReJoin on Kick"), menu_autorejoin, 0, M_MENUTOG, 0, 1},
 	{N_("Auto ReConnect to Server"), menu_autoreconnect, 0, M_MENUTOG, 0, 1},
 	{N_("Never-give-up ReConnect"), menu_autoreconnectonfail, 0, M_MENUTOG, 0, 1},
-	{0, 0, 0, M_SEP, 0, 0},														/* 39 */
+	{0, 0, 0, M_SEP, 0, 0},														/* 38 */
 	{N_("Auto Open Dialog Windows"), menu_autodialog, 0, M_MENUTOG, 0, 1},
 	{N_("Auto Accept DCC Chat"), menu_autodccchat, 0, M_MENUTOG, 0, 1},
 	{N_("Auto Accept DCC Send"), menu_autodccsend, 0, M_MENUTOG, 0, 1},
@@ -1351,12 +1352,12 @@ static struct mymenu mymenu[] = {
 	{N_("Key Bindings..."), menu_keypopup, 0, M_MENU, 0, 1},
 	{0, 0, 0, M_END, 0, 0},
 
-	{0, 0, 0, M_SEP, 0, 0},	/* 56 */
+	{0, 0, 0, M_SEP, 0, 0},	/* 55 */
 	{N_("Reload Settings"), menu_reload, GTK_STOCK_REVERT_TO_SAVED, M_MENUSTOCK, 0, 1},
 	{0, 0, 0, M_SEP, 0, 0},
 	{N_("Save Settings now"), menu_savedefault, GTK_STOCK_SAVE, M_MENUSTOCK, 0, 1},
 	{N_("Save Settings on exit"), menu_saveexit, 0, M_MENUTOG, 1, 1},
-	{N_("Plugins"), 0, 0, M_NEWMENU, 0, 1},	/* 61 */
+	{N_("Plugins"), 0, 0, M_NEWMENU, 0, 1},	/* 60 */
 #ifdef USE_PLUGIN
 	{N_("Load Plugin..."), menu_loadplugin, 0, M_MENU, 0, 1},
 	{N_("Plugin List"), menu_pluginlist, 0, M_MENU, 0, 1},
@@ -1411,17 +1412,17 @@ menu_create_main (int bar, int away,
 	else
 		menu_bar = gtk_menu_new ();
 
-	mymenu[30-menuoffset].state = prefs.invisible;
-	mymenu[31-menuoffset].state = prefs.wallops;
-	mymenu[32-menuoffset].state = prefs.servernotice;
-	mymenu[34-menuoffset].state = away;
-	mymenu[36-menuoffset].state = prefs.autorejoin;
-	mymenu[37-menuoffset].state = prefs.autoreconnect;
-	mymenu[38-menuoffset].state = prefs.autoreconnectonfail;
-	mymenu[40-menuoffset].state = prefs.autodialog;
-	mymenu[41-menuoffset].state = prefs.autodccchat;
-	mymenu[42-menuoffset].state = prefs.autodccsend;
-	mymenu[60-menuoffset].state = prefs.autosave;
+	mymenu[29-menuoffset].state = prefs.invisible;
+	mymenu[30-menuoffset].state = prefs.wallops;
+	mymenu[31-menuoffset].state = prefs.servernotice;
+	mymenu[33-menuoffset].state = away;
+	mymenu[35-menuoffset].state = prefs.autorejoin;
+	mymenu[36-menuoffset].state = prefs.autoreconnect;
+	mymenu[37-menuoffset].state = prefs.autoreconnectonfail;
+	mymenu[39-menuoffset].state = prefs.autodialog;
+	mymenu[40-menuoffset].state = prefs.autodccchat;
+	mymenu[41-menuoffset].state = prefs.autodccsend;
+	mymenu[59-menuoffset].state = prefs.autosave;
 
 	while (1)
 	{
@@ -1470,7 +1471,7 @@ normalitem:
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 			gtk_widget_show (item);
 			gtk_widget_set_sensitive (item, mymenu[i].activate);
-			if (bar && i == 34 - menuoffset)
+			if (bar && i == 33 - menuoffset)
 				*away_item_ret = item;
 			break;
 
