@@ -44,7 +44,7 @@ GdkColor colors[] = {
 	{0, 0xeeee, 0xdddd, 0x2222}, /* 8  yellow */
 	{0, 0x3333, 0xdede, 0x5555}, /* 9  green */
 	{0, 0x0000, 0xcccc, 0xcccc}, /* 10 aqua */
-	{0, 0x3333, 0xdddd, 0xeeee}, /* 11 light aqua */
+	{0, 0x3333, 0xeeee, 0xffff}, /* 11 light aqua */
 	{0, 0x0000, 0x0000, 0xffff}, /* 12 blue */
 	{0, 0xeeee, 0x2222, 0xeeee}, /* 13 light purple */
 	{0, 0x7777, 0x7777, 0x7777}, /* 14 grey */
