@@ -28,8 +28,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
-#include "../pixmaps/globe.h"
-#include "../pixmaps/server.h"
 #include "../pixmaps/admin.h"
 #include "../pixmaps/op.h"
 #include "../pixmaps/hop.h"
@@ -44,12 +42,6 @@ GdkPixbuf *pix_op;
 GdkPixbuf *pix_hop;
 GdkPixbuf *pix_voice;
 
-GdkPixmap *pix_globe;
-GdkPixmap *pix_server;
-
-GdkBitmap *mask_globe;
-GdkBitmap *mask_server;
-
 
 static GdkPixmap *
 pixmap_load_from_file_real (char *file)
@@ -86,19 +78,6 @@ pixmap_load_from_file (char *filename)
 	return pix;
 }
 
-static GdkPixmap *
-pixmap_render (const guint8 *pixdata, GdkBitmap **mask)
-{
-	GdkPixbuf *pixbuf;
-	GdkPixmap *pixmap;
-
-	pixbuf = gdk_pixbuf_new_from_inline (-1, pixdata, FALSE, 0);
-	gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, mask, 128);
-	gdk_pixbuf_unref (pixbuf);
-
-	return pixmap;
-}
-
 void
 pixmaps_init (void)
 {
@@ -109,7 +88,4 @@ pixmaps_init (void)
 	pix_op = gdk_pixbuf_new_from_inline (-1, opxpm, FALSE, 0);
 	pix_hop = gdk_pixbuf_new_from_inline (-1, hopxpm, FALSE, 0);
 	pix_voice = gdk_pixbuf_new_from_inline (-1, voicexpm, FALSE, 0);
-
-	pix_globe = pixmap_render (globexpm, &mask_globe);
-	pix_server = pixmap_render (serverxpm, &mask_server);
 }
