@@ -36,6 +36,7 @@
 #include <gtk/gtktreestore.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkhscale.h>
 
 static int last_selected_page = 0;
 static struct xchatprefs setup_prefs;
@@ -50,6 +51,7 @@ enum
 	ST_MENU,
 	ST_RADIO,
 	ST_NUMBER,
+	ST_HSCALE,
 };
 
 typedef struct
@@ -63,7 +65,7 @@ typedef struct
 } setting;
 
 
-static setting textbox_settings[] =
+static const setting textbox_settings[] =
 {
 	{ST_EFONT,  N_("Font:"), P_OFFSET(font_normal), 0, 0, sizeof prefs.font_normal},
 	{ST_EFILE,  N_("Background image:"), P_OFFSET(background), 0, 0, sizeof prefs.background},
@@ -74,6 +76,19 @@ static setting textbox_settings[] =
 	{ST_TOGGLE, N_("Tint transparency"), P_OFFINT(tint),0,0,0},
 	{ST_TOGGLE, N_("Colored nicks"), P_OFFINT(colorednicks),0,0,0},
 	{ST_TOGGLE, N_("Strip mIRC color"), P_OFFINT(stripcolor),0,0,0},
+	{ST_NUMBER,	N_("Scrollback lines:"), P_OFFINT(max_lines),0,0,100000},
+	{ST_HSCALE, N_("Tint blue:"), P_OFFINT(tint_blue),0,0,0},
+	{ST_HSCALE, N_("Tint red:"), P_OFFINT(tint_red),0,0,0},
+	{ST_HSCALE, N_("Tint green:"), P_OFFINT(tint_green),0,0,0},
+	{ST_END, 0, 0, 0, 0, 0}
+};
+
+static const setting inputbox_settings[] =
+{
+	{ST_TOGGLE, N_("Automatic nick completion"), P_OFFINT(nickcompletion),0,0,0},
+	{ST_TOGGLE, N_("Use the Text box font"), P_OFFINT(style_inputbox),0,0,0},
+	{ST_TOGGLE, N_("Interpret %nnn as an ASCII value"), P_OFFINT(perc_color),0,0,0},
+	{ST_ENTRY, N_("Nick completion suffix:"), P_OFFSET(nick_suffix),0,0,sizeof prefs.nick_suffix},
 	{ST_END, 0, 0, 0, 0, 0}
 };
 
@@ -87,7 +102,7 @@ static char *ulmenutext[] =
 	NULL
 };
 
-static setting userlist_settings[] =
+static const setting userlist_settings[] =
 {
 	{ST_TOGGLE, N_("Show hostnames in userlist"), P_OFFINT(showhostname_in_userlist), 0, 0, 0},
 	{ST_TOGGLE, N_("Userlist buttons enabled"), P_OFFINT(userlistbuttons), 0, 0, 0},
@@ -113,35 +128,37 @@ static char *tabpos[] =
 	NULL
 };
 
-static setting tabs_settings[] =
+static const setting tabs_settings[] =
 {
 	{ST_MENU,	N_("Open channels in:"), P_OFFINT(tabchannels), 0, tabwin, 0},
 	{ST_MENU,	N_("Open dialogs in:"), P_OFFINT(privmsgtab), 0, tabwin, 0},
 	{ST_MENU,	N_("Open utilities in:"), P_OFFINT(windows_as_tabs), N_("Open DCC, Ignore, Notify etc, in tabs or windows?"), tabwin, 0},
 	{ST_MENU,	N_("Show tabs at:"), P_OFFINT(tabs_position), 0, tabpos, 0},
-	{ST_TOGGLE, N_("Open an extra tab for each server"), P_OFFINT(use_server_tab), 0, 0, 0},
+	{ST_TOGGLE, N_("Open extra tab for each server"), P_OFFINT(use_server_tab), 0, 0, 0},
 	{ST_TOGGLE, N_("Only highlight tabs on channel messages"), P_OFFINT(limitedtabhighlight), 0, 0, 0},
-	{ST_TOGGLE, N_("Open an extra tab for server notices"), P_OFFINT(notices_tabs), 0, 0, 0},
+	{ST_TOGGLE, N_("Open extra tab for server notices"), P_OFFINT(notices_tabs), 0, 0, 0},
 	{ST_TOGGLE, N_("Pop new tabs to front"), P_OFFINT(newtabstofront), 0, 0, 0},
 	{ST_END, 0, 0, 0, 0, 0}
 };
 
-static setting filexfer_settings[] =
+static const setting filexfer_settings[] =
 {
 	{ST_ENTRY,	N_("Download files to:"), P_OFFSET(dccdir), 0, 0, sizeof prefs.dccdir},
 	{ST_ENTRY,	N_("DCC IP address:"), P_OFFSET(dcc_ip_str), 0, 0, sizeof prefs.dcc_ip_str},
 	{ST_NUMBER,	N_("First DCC send port:"), P_OFFINT(first_dcc_send_port), 0, 0, 65535},
 	{ST_NUMBER,	N_("Last DCC send port:"), P_OFFINT(last_dcc_send_port), 0, 0, 65535},
 	{ST_TOGGLE, N_("Auto open DCC send list"), P_OFFINT(autoopendccsendwindow), 0, 0, 0},
-	{ST_TOGGLE, N_("Convert spaces to underscore"), P_OFFINT(dcc_send_fillspaces), 0, 0, 0},
+	{ST_TOGGLE, N_("Convert spaces to underscore"), P_OFFINT(dcc_send_fillspaces),
+					N_("In filenames, before sending"), 0, 0},
 	{ST_TOGGLE, N_("Auto open DCC chat list"), P_OFFINT(autoopendccchatwindow), 0, 0, 0},
 	{ST_TOGGLE, N_("Save nickname in filenames"), P_OFFINT(dccwithnick), 0, 0, 0},
 	{ST_TOGGLE, N_("Auto open DCC receive list"), P_OFFINT(autoopendccrecvwindow), 0, 0, 0},
-	{ST_TOGGLE, N_("Get my IP from IRC server"), P_OFFINT(ip_from_server), 0, 0, 0},
+	{ST_TOGGLE, N_("Get my IP from IRC server"), P_OFFINT(ip_from_server),
+					N_("/WHOIS yourself to find your real address"), 0, 0},
 	{ST_END, 0, 0, 0, 0, 0}
 };
 
-static setting general_settings[] =
+static const setting general_settings[] =
 {
 	{ST_ENTRY,	N_("Default quit message:"), P_OFFSET(quitreason), 0, 0, sizeof prefs.quitreason},
 	{ST_ENTRY,	N_("Default part message:"), P_OFFSET(partreason), 0, 0, sizeof prefs.partreason},
@@ -157,7 +174,7 @@ static setting general_settings[] =
 	{ST_END, 0, 0, 0, 0, 0}
 };
 
-static setting logging_settings[] =
+static const setting logging_settings[] =
 {
 	{ST_ENTRY,	N_("Log filename mask:"), P_OFFSET(logmask), 0, 0, sizeof prefs.logmask},
 	{ST_ENTRY,	N_("Log timestamp format:"), P_OFFSET(timestamp_log_format), 0, 0, sizeof prefs.timestamp_log_format},
@@ -176,7 +193,7 @@ static char *proxytypes[] =
 	NULL
 };
 
-static setting network_settings[] =
+static const setting network_settings[] =
 {
 	{ST_ENTRY,	N_("Address to bind to:"), P_OFFSET(hostname), 0, 0, sizeof prefs.hostname},
 	{ST_ENTRY,	N_("Proxy server:"), P_OFFSET(proxy_host), 0, 0, sizeof prefs.proxy_host},
@@ -193,13 +210,13 @@ static setting network_settings[] =
 
 
 static void
-setup_toggle_cb (GtkToggleButton *but, setting *set)
+setup_toggle_cb (GtkToggleButton *but, const setting *set)
 {
 	setup_set_int (&setup_prefs, set, but->active ? 1 : 0);
 }
 
 static void
-setup_create_toggle (GtkWidget *box, int row, setting *set)
+setup_create_toggle (GtkWidget *box, int row, const setting *set)
 {
 	GtkWidget *wid;
 
@@ -207,20 +224,20 @@ setup_create_toggle (GtkWidget *box, int row, setting *set)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid),
 											setup_get_int (&setup_prefs, set));
 	g_signal_connect (G_OBJECT (wid), "toggled",
-							G_CALLBACK (setup_toggle_cb), set);
+							G_CALLBACK (setup_toggle_cb), (gpointer)set);
 	if (set->tooltip)
 		add_tip (wid, set->tooltip);
 	gtk_box_pack_start (GTK_BOX (box), wid, 0, 0, 0);
 }
 
 static void
-setup_spin_cb (GtkSpinButton *spin, setting *set)
+setup_spin_cb (GtkSpinButton *spin, const setting *set)
 {
 	setup_set_int (&setup_prefs, set, gtk_spin_button_get_value_as_int (spin));
 }
 
 static void
-setup_create_spin (GtkWidget *table, int row, setting *set)
+setup_create_spin (GtkWidget *table, int row, const setting *set)
 {
 	GtkWidget *label, *wid, *rbox, *align;
 
@@ -239,10 +256,38 @@ setup_create_spin (GtkWidget *table, int row, setting *set)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (wid),
 										setup_get_int (&setup_prefs, set));
 	g_signal_connect (G_OBJECT (wid), "value-changed",
-							G_CALLBACK (setup_spin_cb), set);
+							G_CALLBACK (setup_spin_cb), (gpointer)set);
 	gtk_box_pack_start (GTK_BOX (rbox), wid, 0, 0, 0);
 }
 
+
+static void
+setup_hscale_cb (GtkHScale *wid, const setting *set)
+{
+	setup_set_int (&setup_prefs, set, gtk_range_get_value(GTK_RANGE(wid)));
+}
+
+static void
+setup_create_hscale (GtkWidget *table, int row, const setting *set)
+{
+	GtkWidget *wid;
+
+	wid = gtk_hscale_new_with_range(0., 255., 1.);
+	gtk_range_set_value (GTK_RANGE (wid), setup_get_int (&setup_prefs, set));
+	g_signal_connect (G_OBJECT(wid), "value_changed",
+							G_CALLBACK (setup_hscale_cb), (gpointer)set);
+	if (set->tooltip)
+		add_tip (wid, set->tooltip);
+
+	gtk_table_attach (GTK_TABLE (table), wid, 1, 5, row, row + 1,
+						GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+
+	wid = gtk_label_new (set->label);
+	gtk_misc_set_alignment (GTK_MISC (wid), 1.0, 1.0);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, row, row + 1,
+						GTK_FILL, GTK_FILL, 0, 0);
+}
+
 #if 0
 static int
 setup_create_radio (GtkWidget *table, int row, setting *set)
@@ -275,14 +320,14 @@ setup_create_radio (GtkWidget *table, int row, setting *set)
 #endif
 
 static void
-setup_menu_cb (GtkWidget *item, setting *set)
+setup_menu_cb (GtkWidget *item, const setting *set)
 {
 	setup_set_int (&setup_prefs, set,
 						GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "n")));
 }
 
 static void
-setup_create_menu (GtkWidget *table, int row, setting *set)
+setup_create_menu (GtkWidget *table, int row, const setting *set)
 {
 	GtkWidget *wid, *menu, *item;
 	int i;
@@ -306,7 +351,7 @@ setup_create_menu (GtkWidget *table, int row, setting *set)
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 		g_signal_connect (G_OBJECT (item), "activate",
-								G_CALLBACK (setup_menu_cb), set);
+								G_CALLBACK (setup_menu_cb), (gpointer)set);
 		i++;
 	}
 
@@ -382,7 +427,7 @@ setup_entry_cb (GtkEntry *entry, setting *set)
 }
 
 static void
-setup_create_entry (GtkWidget *table, int row, setting *set)
+setup_create_entry (GtkWidget *table, int row, const setting *set)
 {
 	GtkWidget *label;
 	GtkWidget *wid, *bwid;
@@ -396,7 +441,7 @@ setup_create_entry (GtkWidget *table, int row, setting *set)
 	gtk_entry_set_max_length (GTK_ENTRY (wid), set->extra);
 	gtk_entry_set_text (GTK_ENTRY (wid), setup_get_str (&setup_prefs, set));
 	g_signal_connect (G_OBJECT (wid), "changed",
-							G_CALLBACK (setup_entry_cb), set);
+							G_CALLBACK (setup_entry_cb), (gpointer)set);
 
 	gtk_table_attach (GTK_TABLE (table), wid, 1, 4, row, row + 1,
 							GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
@@ -416,7 +461,7 @@ setup_create_entry (GtkWidget *table, int row, setting *set)
 }
 
 static GtkWidget *
-setup_create_page (setting *set)
+setup_create_page (const setting *set)
 {
 	int i, row;
 	GtkWidget *tab, *box, *hbox, *left, *right;
@@ -466,6 +511,9 @@ setup_create_page (setting *set)
 		case ST_NUMBER:
 			setup_create_spin (tab, row, &set[i]);
 			break;
+		case ST_HSCALE:
+			setup_create_hscale (tab, row, &set[i]);
+			break;
 		}
 		i++;
 		row++;
@@ -629,6 +677,7 @@ static char *cata[] =
 {
 	N_("Interface"),
 		N_("Text box"),
+		N_("Input box"),
 		N_("User list"),
 		N_("Tabs"),
 		N_("Colors"),
@@ -652,13 +701,14 @@ setup_create_pages (GtkWidget *box)
 	book = gtk_notebook_new ();
 
 	setup_add_page (_(cata[1]), book, setup_create_page (textbox_settings));
-	setup_add_page (_(cata[2]), book, setup_create_page (userlist_settings));
-	setup_add_page (_(cata[3]), book, setup_create_page (tabs_settings));
-	setup_add_page (_(cata[4]), book, setup_create_color_page ());
-	setup_add_page (_(cata[7]), book, setup_create_page (general_settings));
-	setup_add_page (_(cata[8]), book, setup_create_page (logging_settings));
-	setup_add_page (_(cata[11]), book, setup_create_page (network_settings));
-	setup_add_page (_(cata[12]), book, setup_create_page (filexfer_settings));
+	setup_add_page (_(cata[2]), book, setup_create_page (inputbox_settings));
+	setup_add_page (_(cata[3]), book, setup_create_page (userlist_settings));
+	setup_add_page (_(cata[4]), book, setup_create_page (tabs_settings));
+	setup_add_page (_(cata[5]), book, setup_create_color_page ());
+	setup_add_page (_(cata[8]), book, setup_create_page (general_settings));
+	setup_add_page (_(cata[9]), book, setup_create_page (logging_settings));
+	setup_add_page (_(cata[12]), book, setup_create_page (network_settings));
+	setup_add_page (_(cata[13]), book, setup_create_page (filexfer_settings));
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (book), FALSE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (book), FALSE);
