@@ -201,7 +201,6 @@ tab_focus (GtkWidget *tab)
 	tab_pressed_cb (GTK_TOGGLE_BUTTON (tab), group);
 }
 
-
 static void
 tab_add_real (GtkWidget *group, GtkWidget *tab, void *family)
 {
@@ -319,7 +318,6 @@ tab_rename (GtkWidget *tab, char *new_name)
 	gtk_button_set_label (GTK_BUTTON (tab), new_name);
 }
 
-#if 0
 void
 tab_remove (GtkWidget *tab)
 {
@@ -332,7 +330,8 @@ tab_remove (GtkWidget *tab)
 	focus_tab = g_object_get_data (G_OBJECT (group), "foc");
 	if (focus_tab == tab)
 	{
+		focus_tab = 0;
+		g_object_set_data (G_OBJECT (group), "foc", NULL);
 		tab_group_switch (group, 0, FALSE);
 	}
 }
-#endif
