@@ -17,7 +17,6 @@
  */
 
 #include <stdio.h>
-#include <signal.h>
 #include <string.h>
 #include "../../config.h"
 #ifdef HAVE_STRINGS_H
@@ -34,18 +33,15 @@
 
 #include "../common/xchat.h"
 #include "../common/cfgfiles.h"
-#include "../common/util.h"
-#include "../common/xchatc.h"
+#include "../common/url.h"
 #include "gtkutil.h"
 #include "menu.h"
 #include "maingui.h"
 #include "urlgrab.h"
 
 
-static GSList *url_list = 0;
 static GtkWidget *urlgrabberwindow = 0;
 static GtkWidget *urlgrabberlist;
-static void url_addurlgui (char *urltext);
 
 
 static void
@@ -57,58 +53,16 @@ url_closegui (GtkWidget *wid, gpointer userdata)
 static void
 url_button_clear (void)
 {
-	while (url_list)
-	{
-		free (url_list->data);
-		url_list = g_slist_remove (url_list, url_list->data);
-	}
+	url_clear ();
 	gtk_clist_clear (GTK_CLIST (urlgrabberlist));
 }
 
-void
-url_autosave (void)
-{
-	FILE *fd;
-	GSList *list;
-	char *buf;
-
-	buf = malloc (1000);
-	snprintf (buf, 1000, "%s/url.save", get_xdir ());
-
-	fd = fopen (buf, "a");
-	free (buf);
-	if (fd == NULL)
-		return;
-
-	list = url_list;
-
-	while (list)
-	{
-		fprintf (fd, "%s\n", (char *) list->data);
-		list = list->next;
-	}
-
-	fclose (fd);
-}
-
 static void
 url_save_callback (void *arg1, void *arg2, char *file)
 {
-	FILE *fd;
-	GSList *list;
-
 	if (file)
 	{
-		fd = fopen (file, "w");
-		if (fd == NULL)
-			return;
-		list = url_list;
-		while (list)
-		{
-			fprintf (fd, "%s\n", (char *) list->data);
-			list = list->next;
-		}
-		fclose (fd);
+		url_save (file, "w");
 		free (file);
 	}
 }
@@ -144,6 +98,13 @@ url_clicklist (GtkWidget * widget, GdkEventButton * event, gpointer userdata)
 	return FALSE;
 }
 
+void
+fe_url_add (char *urltext)
+{
+	if (urlgrabberwindow)
+		gtk_clist_prepend ((GtkCList *) urlgrabberlist, &urltext);
+}
+
 void
 url_opengui ()
 {
@@ -182,75 +143,7 @@ url_opengui ()
 	list = url_list;
 	while (list)
 	{
-		url_addurlgui ((char *) list->data);
+		fe_url_add ((char *) list->data);
 		list = list->next;
 	}
 }
-
-static void
-url_addurlgui (char *urltext)
-{
-	if (urlgrabberwindow)
-		gtk_clist_prepend ((GtkCList *) urlgrabberlist, &urltext);
-}
-
-static int
-url_findurl (char *urltext)
-{
-	GSList *list = url_list;
-	while (list)
-	{
-		if (!strcasecmp (urltext, (char *) list->data))
-			return 1;
-		list = list->next;
-	}
-	return 0;
-}
-
-static void
-url_addurl (char *urltext)
-{
-	char *data = strdup (urltext);
-	if (!data)
-		return;
-
-	if (data[strlen (data) - 1] == '.')	/* chop trailing dot */
-		data[strlen (data) - 1] = 0;
-
-	if (url_findurl (data))
-	{
-		free (data);
-		return;
-	}
-
-	url_list = g_slist_prepend (url_list, data);
-	url_addurlgui (data);
-}
-
-void
-fe_checkurl (char *buf)
-{
-	char t, *po, *urltext = nocasestrstr (buf, "http:");
-	if (!urltext)
-		urltext = nocasestrstr (buf, "www.");
-	if (!urltext)
-		urltext = nocasestrstr (buf, "ftp.");
-	if (!urltext)
-		urltext = nocasestrstr (buf, "ftp:");
-	if (!urltext)
-		urltext = nocasestrstr (buf, "irc://");
-	if (!urltext)
-		urltext = nocasestrstr (buf, "irc.");
-	if (urltext)
-	{
-		po = strchr (urltext, ' ');
-		if (po)
-		{
-			t = *po;
-			*po = 0;
-			url_addurl (urltext);
-			*po = t;
-		} else
-			url_addurl (urltext);
-	}
-}
