@@ -25,7 +25,7 @@
 #define TINT_VALUE 195				/* 195/255 of the brightness. */
 #define MOTION_MONITOR				/* URL hilights. */
 #define SMOOTH_SCROLL				/* line-by-line or pixel scroll? */
-#define COLOR_HILIGHT				/* Color instead of underline? */
+#undef COLOR_HILIGHT				/* Color instead of underline? */
 
 #define MARGIN 2						/* dont touch. */
 #define REFRESH_TIMEOUT 20
@@ -626,17 +626,17 @@ backend_get_char_width (GtkXText *xtext, unsigned char *str, int *mbl_ret,
 static void
 xtext_set_fg (GtkXText *xtext, GdkGC *gc, int index)
 {
+	GdkColor col;
+
 #ifdef USE_XFT
 	if (gc == xtext->fgc)
 		xtext->xft_fg = &xtext->color[index];
 	else
 		xtext->xft_bg = &xtext->color[index];
-#else
-	GdkColor col;
+#endif
 
 	col.pixel = xtext->palette[index];
 	gdk_gc_set_foreground (gc, &col);
-#endif
 }
 
 #ifdef USE_XFT
@@ -1048,19 +1048,19 @@ gtk_xtext_size_allocate (GtkWidget * widget, GtkAllocation * allocation)
 }
 
 static int
-gtk_xtext_selection_clear (GtkXText * xtext)
+gtk_xtext_selection_clear (xtext_buffer *buf)
 {
 	textentry *ent;
 	int ret = 0;
 
-	ent = xtext->buffer->last_ent_start;
+	ent = buf->last_ent_start;
 	while (ent)
 	{
 		if (ent->mark_start != -1)
 			ret = 1;
 		ent->mark_start = -1;
 		ent->mark_end = -1;
-		if (ent == xtext->buffer->last_ent_end)
+		if (ent == buf->last_ent_end)
 			break;
 		ent = ent->next;
 	}
@@ -1539,7 +1539,7 @@ gtk_xtext_selection_draw (GtkXText * xtext, GdkEventMotion * event)
 		return;
 
 	/* set all the old mark_ fields to -1 */
-	gtk_xtext_selection_clear (xtext);
+	gtk_xtext_selection_clear (xtext->buffer);
 
 	ent_start->mark_start = offset_start;
 	ent_start->mark_end = offset_end;
@@ -1829,6 +1829,12 @@ static void
 gtk_xtext_set_clip_owner (GtkWidget * xtext, GdkEventButton * event)
 {
 	gtk_selection_owner_set (xtext, GDK_SELECTION_PRIMARY, event->time);
+
+	if (GTK_XTEXT (xtext)->selection_buffer &&
+		GTK_XTEXT (xtext)->selection_buffer != GTK_XTEXT (xtext)->buffer)
+		gtk_xtext_selection_clear (GTK_XTEXT (xtext)->selection_buffer);
+
+	GTK_XTEXT (xtext)->selection_buffer = GTK_XTEXT (xtext)->buffer;
 }
 
 static gboolean
@@ -1874,7 +1880,7 @@ gtk_xtext_button_release (GtkWidget * widget, GdkEventButton * event)
 		if (xtext->select_start_x == event->x &&
 			 xtext->select_start_y == event->y)
 		{
-			if (gtk_xtext_selection_clear (xtext))
+			if (gtk_xtext_selection_clear (xtext->buffer))
 			{
 				xtext->skip_border_fills = TRUE;
 				xtext->skip_stamp = TRUE;
@@ -1939,7 +1945,7 @@ gtk_xtext_button_press (GtkWidget * widget, GdkEventButton * event)
 		{
 			if (len == 0)
 				return FALSE;
-			gtk_xtext_selection_clear (xtext);
+			gtk_xtext_selection_clear (xtext->buffer);
 			ent->mark_start = offset;
 			ent->mark_end = offset + len;
 			gtk_xtext_selection_render (xtext, ent, offset, ent, offset + len);
@@ -1954,7 +1960,7 @@ gtk_xtext_button_press (GtkWidget * widget, GdkEventButton * event)
 	{
 		if (gtk_xtext_get_word (xtext, x, y, &ent, 0, 0))
 		{
-			gtk_xtext_selection_clear (xtext);
+			gtk_xtext_selection_clear (xtext->buffer);
 			ent->mark_start = 0;
 			ent->mark_end = ent->str_len;
 			gtk_xtext_selection_render (xtext, ent, 0, ent, ent->str_len);
@@ -1992,7 +1998,7 @@ static gboolean
 gtk_xtext_selection_kill (GtkXText *xtext, GdkEventSelection *event)
 {
 #ifndef WIN32
-	if (gtk_xtext_selection_clear (xtext))
+	if (gtk_xtext_selection_clear (xtext->buffer))
 	{
 		xtext->skip_border_fills = TRUE;
 		xtext->skip_stamp = TRUE;
@@ -2023,10 +2029,15 @@ gtk_xtext_selection_get (GtkWidget * widget,
 	guchar *new_text;
 	int len;
 	int first = TRUE;
+	xtext_buffer *buf;
+
+	buf = xtext->selection_buffer;
+	if (!buf)
+		return;
 
 	/* first find out how much we need to malloc ... */
 	len = 0;
-	ent = xtext->buffer->last_ent_start;
+	ent = buf->last_ent_start;
 	while (ent)
 	{
 		if (ent->mark_start != -1)
@@ -2036,7 +2047,7 @@ gtk_xtext_selection_get (GtkWidget * widget,
 			else
 				len++;
 		}
-		if (ent == xtext->buffer->last_ent_end)
+		if (ent == buf->last_ent_end)
 			break;
 		ent = ent->next;
 	}
@@ -2046,7 +2057,7 @@ gtk_xtext_selection_get (GtkWidget * widget,
 
 	/* now allocate mem and copy buffer */
 	pos = txt = malloc (len);
-	ent = xtext->buffer->last_ent_start;
+	ent = buf->last_ent_start;
 	while (ent)
 	{
 		if (ent->mark_start != -1)
@@ -2064,7 +2075,7 @@ gtk_xtext_selection_get (GtkWidget * widget,
 				pos += ent->mark_end - ent->mark_start;
 			}
 		}
-		if (ent == xtext->buffer->last_ent_end)
+		if (ent == buf->last_ent_end)
 			break;
 		ent = ent->next;
 	}
@@ -3834,7 +3845,7 @@ gtk_xtext_search (GtkXText * xtext, const unsigned char *text, void *start)
 	unsigned char *str;
 	int line;
 
-	gtk_xtext_selection_clear (xtext);
+	gtk_xtext_selection_clear (xtext->buffer);
 	xtext->buffer->last_ent_start = NULL;
 	xtext->buffer->last_ent_end = NULL;
 
@@ -4164,6 +4175,8 @@ gtk_xtext_buffer_show (GtkXText *xtext, xtext_buffer *buf)
 	if (xtext->buffer == buf)
 		return;
 
+//printf("text_buffer_show: xtext=%p buffer=%p\n", xtext, buf);
+
 	gdk_drawable_get_size (GTK_WIDGET (xtext)->window, &w, &h);
 
 	if (xtext->buffer)
@@ -4227,6 +4240,9 @@ gtk_xtext_buffer_free (xtext_buffer *buf)
 	if (buf->xtext->buffer == buf)
 		buf->xtext->buffer = buf->xtext->orig_buffer;
 
+	if (buf->xtext->selection_buffer == buf)
+		buf->xtext->selection_buffer = NULL;
+
 	ent = buf->text_first;
 	while (ent)
 	{
