@@ -90,6 +90,8 @@ fe_new_window (struct session *sess)
 
 	if (!sess->server->front_session)
 		sess->server->front_session = sess;
+	if (!sess->server->server_session)
+		sess->server->server_session = sess;
 	if (!current_tab)
 		current_tab = sess;
 
@@ -428,7 +430,7 @@ fe_init (void)
 	prefs.use_server_tab = 0;
 	prefs.autodialog = 0;
 	prefs.lagometer = 0;
-	prefs.skipserverlist = 1;
+	prefs.slist_skip = 1;
 }
 
 void
@@ -705,7 +707,7 @@ fe_server_callback (struct server *serv)
 {
 }
 void
-fe_checkurl (char *text)
+fe_url_add (const char *text)
 {
 }
 void
@@ -780,8 +782,7 @@ void
 fe_set_away (server *serv)
 {
 }
-int
-fe_open_serverlist (session *sess, int auto_connect, int dont_show)
+void
+fe_serverlist_open (session *sess)
 {
-	return FALSE;
 }
